[gpsprune] 01/05: Imported Upstream version 18.1

Sebastiaan Couwenberg sebastic at moszumanska.debian.org
Fri Oct 2 10:58:27 UTC 2015


This is an automated email from the git hooks/post-receive script.

sebastic pushed a commit to branch master
in repository gpsprune.

commit f54fd6a8b9fa5e65204225216ec4906a01192eb6
Author: Bas Couwenberg <sebastic at xs4all.nl>
Date:   Fri Oct 2 12:40:34 2015 +0200

    Imported Upstream version 18.1
---
 build.sh                                          |   2 +-
 tim/prune/GpsPrune.java                           |   4 +-
 tim/prune/UpdateMessageBroker.java                |  35 +-
 tim/prune/data/Selection.java                     |   8 +-
 tim/prune/data/SpeedCalculator.java               |  36 +-
 tim/prune/data/Timestamp.java                     |  10 +-
 tim/prune/function/GetWikipediaFunction.java      |  72 ++-
 tim/prune/function/PhotoPopupFunction.java        |  49 +-
 tim/prune/function/charts/Charter.java            |   2 +-
 tim/prune/function/gpsies/TrackListModel.java     |  17 +-
 tim/prune/function/search/SearchResult.java       |  19 +-
 tim/prune/function/search/wikimedia_galleries.txt | 662 ++++++++++++++++++++++
 tim/prune/lang/prune-texts_cz.properties          |   1 +
 tim/prune/lang/prune-texts_de.properties          |   3 +-
 tim/prune/lang/prune-texts_de_CH.properties       |   1 +
 tim/prune/lang/prune-texts_en.properties          |   1 +
 tim/prune/lang/prune-texts_hu.properties          |   1 +
 tim/prune/lang/prune-texts_nl.properties          |   8 +
 tim/prune/lang/prune-texts_ro.properties          |   1 +
 tim/prune/lang/prune-texts_uk.properties          |  36 +-
 tim/prune/readme.txt                              |  16 +-
 21 files changed, 929 insertions(+), 55 deletions(-)

diff --git a/build.sh b/build.sh
index 2c5b85d..dc93bd6 100644
--- a/build.sh
+++ b/build.sh
@@ -1,6 +1,6 @@
 # Build script using external exif library
 # Version number
-PRUNENAME=gpsprune_18
+PRUNENAME=gpsprune_18.1
 # remove compile directory
 rm -rf compile
 # remove dist directory
diff --git a/tim/prune/GpsPrune.java b/tim/prune/GpsPrune.java
index 1f76d16..303453a 100644
--- a/tim/prune/GpsPrune.java
+++ b/tim/prune/GpsPrune.java
@@ -36,9 +36,9 @@ import tim.prune.gui.profile.ProfileChart;
 public class GpsPrune
 {
 	/** Version number of application, used in about screen and for version check */
-	public static final String VERSION_NUMBER = "18";
+	public static final String VERSION_NUMBER = "18.1";
 	/** Build number, just used for about screen */
-	public static final String BUILD_NUMBER = "334";
+	public static final String BUILD_NUMBER = "336";
 	/** Static reference to App object */
 	private static App APP = null;
 
diff --git a/tim/prune/UpdateMessageBroker.java b/tim/prune/UpdateMessageBroker.java
index b584ed8..1659973 100644
--- a/tim/prune/UpdateMessageBroker.java
+++ b/tim/prune/UpdateMessageBroker.java
@@ -6,11 +6,11 @@ package tim.prune;
  */
 public abstract class UpdateMessageBroker
 {
-	private static final int MAXIMUM_NUMBER_SUBSCRIBERS = 7;
+	private static final int MAXIMUM_NUMBER_SUBSCRIBERS = 8;
 	/** Array of all subscribers */
 	private static DataSubscriber[] _subscribers = new DataSubscriber[MAXIMUM_NUMBER_SUBSCRIBERS];
-	/** Counter of the number of subscribers added so far */
-	private static int _subscriberNum = 0;
+	/** Index from which to start looking for an empty slot*/
+	private static int _searchStartIndex = 0;
 	/** Enable/disabled flag */
 	private static boolean _enabled = true;
 
@@ -21,8 +21,33 @@ public abstract class UpdateMessageBroker
 	 */
 	public static void addSubscriber(DataSubscriber inSub)
 	{
-		_subscribers[_subscriberNum] = inSub;
-		_subscriberNum++;
+		// Loop looking for first null entry
+		for (int i=_searchStartIndex; i<MAXIMUM_NUMBER_SUBSCRIBERS; i++)
+		{
+			if (_subscribers[i] == null)
+			{
+				_subscribers[i] = inSub;
+				_searchStartIndex = i+1;
+				break;
+			}
+		}
+	}
+
+	/**
+	 * Remove the given subscriber from the list
+	 * @param inSub subscriber to remove
+	 */
+	public static void removeSubscriber(DataSubscriber inSub)
+	{
+		for (int i=0; i<MAXIMUM_NUMBER_SUBSCRIBERS; i++)
+		{
+			if (_subscribers[i] == inSub)
+			{
+				_subscribers[i] = null;
+				// Could break out of the loop here but we want to make sure we remove all of them
+			}
+		}
+		_searchStartIndex = 0; // for the next add, start from beginning to ensure all gaps are filled
 	}
 
 	/**
diff --git a/tim/prune/data/Selection.java b/tim/prune/data/Selection.java
index 68654e8..7b63d70 100644
--- a/tim/prune/data/Selection.java
+++ b/tim/prune/data/Selection.java
@@ -17,7 +17,7 @@ public class Selection
 	private int _currentPhotoIndex = -1;
 	private int _currentAudioIndex = -1;
 	private AltitudeRange _altitudeRange = null;
-	private long _movingSeconds = 0L;
+	private long _movingMilliseconds = 0L;
 	private double _angMovingDistance = -1.0;
 
 
@@ -77,7 +77,7 @@ public class Selection
 			Timestamp time = null, previousTime = null;
 			DataPoint lastPoint = null, currPoint = null;
 			_angMovingDistance = 0.0;
-			_movingSeconds = 0L;
+			_movingMilliseconds = 0L;
 			// Loop over points in selection
 			for (int i=_startIndex; i<=_endIndex; i++)
 			{
@@ -99,7 +99,7 @@ public class Selection
 				{
 					// add moving time
 					if (!currPoint.getSegmentStart() && previousTime != null && time.isAfter(previousTime)) {
-						_movingSeconds += time.getSecondsSince(previousTime);
+						_movingMilliseconds += time.getMillisecondsSince(previousTime);
 					}
 					previousTime = time;
 				}
@@ -156,7 +156,7 @@ public class Selection
 	public long getMovingSeconds()
 	{
 		if (!_valid) recalculate();
-		return _movingSeconds;
+		return _movingMilliseconds / 1000L;
 	}
 
 	/**
diff --git a/tim/prune/data/SpeedCalculator.java b/tim/prune/data/SpeedCalculator.java
index e80e214..49fd056 100644
--- a/tim/prune/data/SpeedCalculator.java
+++ b/tim/prune/data/SpeedCalculator.java
@@ -50,14 +50,14 @@ public abstract class SpeedCalculator
 				do
 				{
 					p = inTrack.getPoint(index);
-					boolean timeOk = p != null && p.hasTimestamp() && !p.getTimestamp().isAfter(point.getTimestamp());
+					boolean timeOk = p != null && p.hasTimestamp() && p.getTimestamp().isBefore(point.getTimestamp());
 					boolean pValid = timeOk && !p.isWaypoint();
 					if (pValid) {
 						totalRadians += DataPoint.calculateRadiansBetween(p, q);
 						earlyStamp = p.getTimestamp();
 					}
-					stop = (p == null) || (p.hasTimestamp() && !p.getTimestamp().isEqual(point.getTimestamp())
-						|| p.getSegmentStart());
+
+					stop = (p == null) || p.getSegmentStart() || hasSufficientTimeDifference(p, point);
 					index--;
 					if (p != null && !p.isWaypoint()) {
 						q = p;
@@ -78,8 +78,8 @@ public abstract class SpeedCalculator
 					totalRadians += DataPoint.calculateRadiansBetween(p, q);
 					lateStamp = p.getTimestamp();
 				}
-				stop = (p == null) || (p.hasTimestamp() && !p.getTimestamp().isEqual(point.getTimestamp())
-					|| p.getSegmentStart());
+
+				stop = (p == null) || p.getSegmentStart() || hasSufficientTimeDifference(point,  p);
 				index++;
 				if (p != null && !p.isWaypoint()) {
 					q = p;
@@ -146,14 +146,14 @@ public abstract class SpeedCalculator
 				do
 				{
 					p = inTrack.getPoint(index);
-					boolean timeOk = p != null && p.hasTimestamp() && !p.getTimestamp().isAfter(point.getTimestamp());
+					boolean timeOk = p != null && p.hasTimestamp() && p.getTimestamp().isBefore(point.getTimestamp());
 					boolean pValid = timeOk && !p.isWaypoint();
 					if (pValid) {
 						earlyStamp = p.getTimestamp();
 						if (p.hasAltitude()) firstAlt = p.getAltitude();
 					}
-					stop = (p == null) || (p.hasTimestamp() && !p.getTimestamp().isEqual(point.getTimestamp())
-						|| p.getSegmentStart());
+
+					stop = (p == null) || p.getSegmentStart() || hasSufficientTimeDifference(p,  point);
 					index--;
 				}
 				while (!stop);
@@ -172,8 +172,8 @@ public abstract class SpeedCalculator
 					lateStamp = p.getTimestamp();
 					if (p.hasAltitude()) lastAlt = p.getAltitude();
 				}
-				stop = (p == null) || (p.hasTimestamp() && !p.getTimestamp().isEqual(point.getTimestamp())
-					|| p.getSegmentStart());
+
+				stop = (p == null) || p.getSegmentStart() || hasSufficientTimeDifference(point,  p);
 				index++;
 			}
 			while (!stop);
@@ -194,4 +194,20 @@ public abstract class SpeedCalculator
 			inValue.setValue(speedValue);
 		}
 	}
+
+	/**
+	 * Check whether the time difference between P1 and P2 is sufficiently large
+	 * @param inP1 earlier point
+	 * @param inP2 later point
+	 * @return true if we can stop looking now, found a point early/late enough
+	 */
+	private static boolean hasSufficientTimeDifference(DataPoint inP1, DataPoint inP2)
+	{
+		if (inP1 == null || inP2 == null)
+			return true; // we have to give up now
+		if (!inP1.hasTimestamp() || !inP2.hasTimestamp())
+			return false; // keep looking
+		final long MIN_TIME_DIFFERENCE_MS = 1000L;
+		return inP2.getTimestamp().getMillisecondsSince(inP1.getTimestamp()) >= MIN_TIME_DIFFERENCE_MS;
+	}
 }
diff --git a/tim/prune/data/Timestamp.java b/tim/prune/data/Timestamp.java
index cfddffe..d5e065d 100644
--- a/tim/prune/data/Timestamp.java
+++ b/tim/prune/data/Timestamp.java
@@ -362,11 +362,11 @@ public class Timestamp
 	}
 	/**
 	 * @param inOther other Timestamp
-	 * @return true if this one is at least a second after the other
+	 * @return true if this one is at least a millisecond after the other
 	 */
 	public boolean isAfter(Timestamp inOther)
 	{
-		return getSecondsSince(inOther) > 0L;
+		return getMillisecondsSince(inOther) > 0L;
 	}
 
 	/**
@@ -391,11 +391,11 @@ public class Timestamp
 
 	/**
 	 * @param inOther other timestamp to compare
-	 * @return true if they're equal to the nearest second
+	 * @return true if they're equal to the nearest millisecond
 	 */
 	public boolean isEqual(Timestamp inOther)
 	{
-		return getSecondsSince(inOther) == 0L;
+		return inOther != null && _milliseconds == inOther._milliseconds;
 	}
 
 	/**
@@ -404,7 +404,7 @@ public class Timestamp
 	 */
 	public boolean isBefore(Timestamp inOther)
 	{
-		return getSecondsSince(inOther) < 0L;
+		return getMillisecondsSince(inOther) < 0L;
 	}
 
 	/**
diff --git a/tim/prune/function/PhotoPopupFunction.java b/tim/prune/function/PhotoPopupFunction.java
index da9c5ca..077a307 100644
--- a/tim/prune/function/PhotoPopupFunction.java
+++ b/tim/prune/function/PhotoPopupFunction.java
@@ -8,21 +8,26 @@ import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.awt.event.KeyEvent;
 import java.awt.event.KeyListener;
+import java.awt.event.WindowAdapter;
+import java.awt.event.WindowEvent;
 
 import javax.swing.JButton;
+import javax.swing.JDialog;
 import javax.swing.JFrame;
 import javax.swing.JLabel;
 import javax.swing.JPanel;
 import tim.prune.App;
+import tim.prune.DataSubscriber;
 import tim.prune.GenericFunction;
 import tim.prune.I18nManager;
+import tim.prune.UpdateMessageBroker;
 import tim.prune.data.Photo;
 import tim.prune.gui.PhotoThumbnail;
 
 /**
  * Class to show a popup window for a photo
  */
-public class PhotoPopupFunction extends GenericFunction
+public class PhotoPopupFunction extends GenericFunction implements DataSubscriber
 {
 	/** popup window */
 	private JFrame _frame = null; // would be a JDialog but that doesn't allow max button
@@ -59,15 +64,27 @@ public class PhotoPopupFunction extends GenericFunction
 			_frame.getContentPane().add(makeContents());
 			_frame.pack();
 			_frame.setLocationRelativeTo(_parentFrame);
+			_frame.setDefaultCloseOperation(JDialog.DISPOSE_ON_CLOSE);
+			_frame.addWindowListener(new WindowAdapter() {
+				public void windowClosed(WindowEvent e) {
+					UpdateMessageBroker.removeSubscriber(PhotoPopupFunction.this);
+					super.windowClosed(e);
+				}
+			});
 		}
 		initFrame();
 		final Photo photo = _app.getTrackInfo().getCurrentPhoto();
-		if (photo.getWidth() <= 0 || photo.getHeight() <= 0) {
+		if (photo.getWidth() <= 0 || photo.getHeight() <= 0)
+		{
+			_frame.setVisible(false);
 			_app.showErrorMessageNoLookup(getNameKey(), I18nManager.getText("error.showphoto.failed")
 			 + " : " + photo.getName());
 		}
-		else {
+		else
+		{
 			_frame.setVisible(true);
+			// Add listener to Broker
+			UpdateMessageBroker.addSubscriber(this);
 		}
 	}
 
@@ -76,11 +93,18 @@ public class PhotoPopupFunction extends GenericFunction
 	 */
 	private void initFrame()
 	{
-		_frame.setVisible(false);
 		Photo photo = _app.getTrackInfo().getCurrentPhoto();
-		_frame.setTitle(photo.getName());
-		_label.setText("'" + photo.getName() + "' ("
-			+ photo.getWidth() + " x " + photo.getHeight() + ")");
+		if (photo == null)
+		{
+			_frame.setTitle("GpsPrune - " + I18nManager.getText("details.nophoto"));
+			_label.setText(I18nManager.getText("details.nophoto"));
+		}
+		else
+		{
+			_frame.setTitle(photo.getName());
+			_label.setText("'" + photo.getName() + "' ("
+				+ photo.getWidth() + " x " + photo.getHeight() + ")");
+		}
 		_photoThumb.setPhoto(photo);
 	}
 
@@ -117,4 +141,15 @@ public class PhotoPopupFunction extends GenericFunction
 		mainPanel.add(okPanel, BorderLayout.SOUTH);
 		return mainPanel;
 	}
+
+	public void dataUpdated(byte inUpdateType)
+	{
+		// Update photo if selection changes
+		if ((inUpdateType & DataSubscriber.SELECTION_CHANGED) > 0)
+		{
+			initFrame();
+		}
+	}
+
+	public void actionCompleted(String inMessage) {}
 }
diff --git a/tim/prune/function/charts/Charter.java b/tim/prune/function/charts/Charter.java
index ef3cc95..5b7ae83 100644
--- a/tim/prune/function/charts/Charter.java
+++ b/tim/prune/function/charts/Charter.java
@@ -485,7 +485,7 @@ public class Charter extends GenericFunction
 			if (currPoint.hasTimestamp())
 			{
 				if (!currPoint.getSegmentStart() && prevTimestamp != null) {
-					seconds += (currPoint.getTimestamp().getSecondsSince(prevTimestamp));
+					seconds += (currPoint.getTimestamp().getMillisecondsSince(prevTimestamp) / 1000.0);
 				}
 				values.setData(i, seconds / 60.0 / 60.0);
 				prevTimestamp = currPoint.getTimestamp();
diff --git a/tim/prune/function/gpsies/TrackListModel.java b/tim/prune/function/gpsies/TrackListModel.java
index 298578c..94ce503 100644
--- a/tim/prune/function/gpsies/TrackListModel.java
+++ b/tim/prune/function/gpsies/TrackListModel.java
@@ -2,6 +2,7 @@ package tim.prune.function.gpsies;
 
 import java.text.NumberFormat;
 import java.util.ArrayList;
+import java.util.Collections;
 
 import javax.swing.table.AbstractTableModel;
 
@@ -97,10 +98,24 @@ public class TrackListModel extends AbstractTableModel
 	 */
 	public void addTracks(ArrayList<SearchResult> inList)
 	{
+		addTracks(inList, false);
+	}
+
+	/**
+	 * Add a list of tracks to this model and optionally sort them
+	 * @param inList list of tracks to add
+	 * @param inSort true to sort results after adding
+	 */
+	public void addTracks(ArrayList<SearchResult> inList, boolean inSort)
+	{
 		if (_trackList == null) {_trackList = new ArrayList<SearchResult>();}
 		final int prevCount = _trackList.size();
-		if (inList != null && inList.size() > 0) {
+		if (inList != null && inList.size() > 0)
+		{
 			_trackList.addAll(inList);
+			if (inSort) {
+				Collections.sort(_trackList);
+			}
 		}
 		final int updatedCount = _trackList.size();
 		if (prevCount <= 0)
diff --git a/tim/prune/function/search/SearchResult.java b/tim/prune/function/search/SearchResult.java
index 2a05a8c..562f5a4 100644
--- a/tim/prune/function/search/SearchResult.java
+++ b/tim/prune/function/search/SearchResult.java
@@ -3,7 +3,7 @@ package tim.prune.function.search;
 /**
  * Class to hold a search result from wikipedia / gpsies / panoramio etc
  */
-public class SearchResult
+public class SearchResult implements Comparable<SearchResult>
 {
 	/** Track name or title */
 	private String _trackName = null;
@@ -126,4 +126,21 @@ public class SearchResult
 	public String getLongitude() {
 		return _longitude;
 	}
+
+	/**
+	 * Compare two search results for sorting (nearest first, then alphabetic)
+	 */
+	public int compareTo(SearchResult inOther)
+	{
+		double distDiff = getLength() - inOther.getLength();
+		if (distDiff < 0.0)
+		{
+			return -1;
+		}
+		if (distDiff > 0.0)
+		{
+			return 1;
+		}
+		return getTrackName().compareTo(inOther.getTrackName());
+	}
 }
diff --git a/tim/prune/function/search/wikimedia_galleries.txt b/tim/prune/function/search/wikimedia_galleries.txt
new file mode 100644
index 0000000..f8514f5
--- /dev/null
+++ b/tim/prune/function/search/wikimedia_galleries.txt
@@ -0,0 +1,662 @@
+A Arnoia		42 14 54.95 N	8 08 04.88 W
+A Barciela, Oroso		42 57 57.49 N	8 26 31.07 W
+A Cañiza	A Cañiza is a municipality in Galicia, in the province of Pontevedra.	42 12 45.46 N	8 16 29.77 W
+A Coruña		43 21 58.95 N	8 24 28.71 W
+A Guarda		41 54 09.12 N	8 52 27.14 W
+A Gudiña	A Gudiña is a municipality in Galicia, in the province of Ourense.	42 03 40.13 N	7 08 34.19 W
+A Illa de Arousa	A Illa de Arousa is a municipality in Galicia, in the province of Pontevedra.	42 33 08.36 N	8 52 06.13 W
+A Merca	A Merca is a municipality in Galicia, in the province of Ourense.	42 13 22.53 N	7 54 15.55 W
+A Mezquita		42 00 42.5 N	7 02 43.17 W
+A Pobra de Trives		42 20 19.97 N	7 15 15.88 W
+A Pobra do Brollón		42 33 29.3 N	7 23 40.15 W
+A Pobra do Caramiñal	A Pobra do Caramiñal is a municipality in the province of A Coruña, Galicia, Spain.	42 36 12.2 N	8 56 14.25 W
+A Rúa	A Rúa is a municipality in Galicia, in the province of Ourense.	42 23 34.93 N	7 06 59.02 W
+A Veiga	A Veiga is a municipality in Galicia, in the province of Ourense.	42 15 01.36 N	7 01 30.25 W
+A Walk on Main Street, Ferndale, California	Ferndale is a small town in Eureka County, California. Its Main Street is listed by the National Register of Historic Places as a historic district.	40 34 32.16 N	124 15 54 W
+A Walk up Main Street, Adamstown, Pennsylvania	Adamstown is a small, historic town in Lancaster County, Pennsylvania.	40 14 36.96 N	76 03 16.2 W
+Abeilhan		43 27 02 N	3 17 43 E
+Aceldama	Aceldama or Akeldama is the Aramaic name for a place in Jerusalem associated with Judas Iscariot, one of the followers of Jesus.	31 46 05.1 N	35 13 59.51 E
+Adissan		43 32 09.96 N	3 25 45.12 E
+Agel		43 20 18.96 N	2 51 13.68 E
+Agrón, Ames		42 54 20.32 N	8 41 43.21 W
+Aguiño, Ribeira		42 31 24.99 N	9 00 57.6 W
+Alagna Valsesia	Alagna Valsesia is a village in Piemonte in Italy.	45 51 05.15 N	7 56 16.98 E
+Albrechtsburg	The Albrechtsburg is the castle that dominates the city centre of Meißen, Germany.	51 09 59.65 N	13 28 17.83 E
+Aletsch	Aletsch region, UNESCO World Heritage Site since 2001, in Bernese Alps, Switzerland	46 27 50.9 N	8 04 20.89 E
+Allariz	Allariz is a municipality in Galicia, in the province of Ourense.	42 11 20.76 N	7 48 09.71 W
+Alt Katholische Christuskirche Offenbach		50 06 01.91 N	8 45 52.28 E
+Ames		42 51 35.95 N	8 38 58.21 W
+Amoeiro		42 24 37.45 N	7 57 15.38 W
+Ansemil, Silleda		42 44 21.56 N	8 16 12.47 W
+Anta de Casaínhos		38 52 50.16 N	9 10 09.91 W
+Antwerp Central Station		51 13 02 N	4 25 15.6 E
+Aquis Querquennis	Aquis Querquennis was a Roman castra at Os Baños, Bande (Ourense, Galiza).	41 58 27.2 N	7 58 52.1 W
+Arbo		42 06 39.45 N	8 18 57.47 W
+Arch of Constantine		41 53 23 N	12 29 27 E
+Arch of Septimius Severus (Rome)	The Arch of Septimius Severus is situated in the Forum Romanum in Rome.	41 53 34 N	12 29 05 E
+Arch of Titus	The Arch of Titus is a triumphal arch with a single arched opening, located on the Summa Sacra Via to the west of the Roman Forum in Rome.	41 53 26 N	12 29 19 E
+Arenys de Munt	Arenys de Munt is a village in the comarca of Maresme, Catalonia.	41 36 46 N	2 32 25 E
+Artwork:La Nouvelle Liberté		4 03 51.2 N	9 42 24.97 E
+Artwork:Lucas Grandin, Le jardin sonore de Bonamouti		4 04 19.3 N	9 42 37.91 E
+Artwork:Pascale Marthine Tayou, La Colonne Pascale		4 01 34.12 N	9 42 22.84 E
+Artwork:Tracey Rose, Oasis		4 01 28.09 N	9 42 32.75 E
+As Neves	As Neves is a municipality in Galicia, in the province of Pontevedra.	42 05 10.49 N	8 24 53.43 W
+As Pontes de García Rodríguez		43 26 47.63 N	7 51 09.54 W
+Askersund		58 53 00 N	14 54 00 E
+Assumption Cathedral in Odessa	Assumption Cathedral in Odessa, Ukraine	46 28 49.43 N	30 44 21.24 E
+Australian Synchrotron		37 54 51 S	145 08 33 E
+Avión	Avión is a municipality in Galicia, in the province of Ourense.	42 22 23.72 N	8 15 02.64 W
+Ayasofya	The Church of the Holy Wisdom, commonly known as Hagia Sophia in English, is the former Greek Orthodox patriarchal cathedral, converted in 1453 to a mosque, now a museum, in Istanbul.	41 00 30.5 N	28 58 47.7 E
+Bahnhof Dresden-Neustadt	Dresden-Neustadt railway station and the four inner city bridges	51 03 56 N	13 44 27 E
+Baiona	Baiona is a municipality in Galicia, Spain in the province of Pontevedra.	42 07 03.29 N	8 51 01.86 W
+Baltar	Baltar is a municipality in Galicia, in the province of Ourense.	41 57 04.75 N	7 42 56.7 W
+Barbadás		42 17 56.03 N	7 53 13.13 W
+Beade	Beade is a municipality in Galicia, in the province of Ourense.	42 20 06.72 N	8 08 45.05 W
+Beamish Museum: Entrance area	The entrance to Beamish Museum is on the south side of the site.	54 52 54.04 N	1 39 30.93 W
+Bergfriedhof (Stuttgart)	The Bergfriedhof is a cemetery in the Stadtbezirk Stuttgart-Ost in Stuttgart.	48 47 19.16 N	9 12 23.35 E
+Bergondo		43 19 15.35 N	8 13 54.04 W
+Berlin Anhalter Bahnhof	The Anhalter Bahnhof was a large main-line railway station in Berlin. Today it is just a stop on the Berlin S-Bahn.	52 30 11 N	13 22 55 E
+Betanzos		43 16 44.24 N	8 12 55.95 W
+Biella		45 34 05.07 N	8 03 02.61 E
+Bienertparks in Dresden	Als Bienertpark werden verschiedene Parkanlagen in Dresden bezeichnet, deren Entstehung auf die Familie Gottlieb Traugott Bienert zurückgeht.	51 01 48.29 N	13 42 54.9 E
+Bildstock Austraße, Burggrumbach		49 52 19.59 N	10 01 43.48 E
+Bildstock Herrngasse 1, Grafenrheinfeld		50 00 11.52 N	10 11 54.6 E
+Bildstock Mainbacher Weg, Holzhausen		50 07 06.2 N	10 11 07.12 E
+Bildstock Schulstraße 2, Burggrumbach		49 52 13.11 N	10 02 14.06 E
+Boccadasse	Boccadasse è un antico borgo marinaro situato nel levante di Genova.	44 23 23.85 N	8 58 22.71 E
+Boettcherstrasse		53 04 30 N	8 48 21 E
+Boiro		42 38 13.16 N	8 52 12.31 W
+Boke	Boke is a small village in the German district Paderborn; it belongs to the city of Delbrück.	51 43 48 N	8 33 43.56 E
+Bolongaropalast	The Bolongaro Palace ist a baroque building in Frankfurt-Höchst.	50 06 04 N	8 33 08 E
+Borne des Trois Puissances	Dreiländerstein	47 30 10.58 N	7 07 48.76 E
+Borovsk	Эта страница на русском: Боровск	55 12 27.19 N	36 29 05.05 E
+Bosco delle Querce	The Regional Natural Park Bosco delle Querce (Oaks' Wood), built after the Seveso Disaster on the "A" zone.	45 38 55 N	9 09 10 E
+Botanischer Garten Heidelberg		49 25 00 N	8 40 10 E
+Brudermühlbrücke	The Brudermühlbrücke is a bridge in Munich across the Isar.	48 06 45.3 N	11 33 36.07 E
+Brudermühlstraße	The Brudermühlstraße is a street in Munich, part of the Mittlerer Ring around the city centre.	48 06 44.2 N	11 33 01.37 E
+Buenos Aires		34 36 13 S	58 22 54 W
+Bueu	Bueu is a municipality in Galicia, Spain in the province of Pontevedra.	42 19 24.69 N	8 47 23.1 W
+Buffalo Central Terminal	The New York Central Terminal in Buffalo, USA, was a key railroad station from 1929 to 1979.	42 53 22.44 N	78 49 51.08 W
+Burg Stahleck	Stahleck Castle in Bacharach is a 12th century castle occupying a commanding view of the Rhine in the Loreley valley. Nowadays it's a youth hostel.	50 03 29.49 N	7 45 56.46 E
+Burj Khalifa	The Burj Khalifa ("Khalifa Tower") is a skyscraper in Dubai, United Arab Emirates.	25 11 49.7 N	55 16 26.8 E
+Bürgerhospital (Stuttgart)		48 47 34.6 N	9 10 45.95 E
+Cabanas		43 24 50.49 N	8 10 04.15 W
+Cabo Fisterra		42 52 50.96 N	9 16 18.27 W
+Cabrils		41 31 42 N	2 22 09 E
+Cadaqués	Cadaqués is a touristic village in Costa Brava, Alt Empordà, Catalonia, Spain	42 17 19.46 N	3 16 40.96 E
+Cal Becs (Puig-reig)		41 57 41.01 N	1 54 21.89 E
+Calgary		51 02 42 N	114 03 26 W
+Cambados		42 30 52.2 N	8 48 24.89 W
+Cambre	Cambre is a municipality in the province A Coruña, Galicia, Spain.	43 17 37.32 N	8 20 34.49 W
+Campo de' Fiori		41 53 43.94 N	12 28 20.06 E
+Candelabro de Paracas	The Paracas Candelabra is a well-known prehistoric geoglyph found on the northern face of the Paracas Peninsula at Pisco Bay in Peru.	13 47 39.67 S	76 18 31.31 W
+Cangas		42 15 47.09 N	8 47 09.5 W
+Cape Horn	Cape Horn is often said to be the southernmost point of South America.	55 58 47 S	67 16 18 W
+Capela de São Nicolau	Capela de São Nicolau ou Passos da Via Sacra. Em Portugal, Porto.	41 08 27.14 N	8 36 55.49 W
+Capriata d'Orba	Capriata d'Orba è un comune in provincia di Alessandria, Piemonte, Italia.	44 43 43.93 N	8 41 25.29 E
+Carballeda de Avia	Carballeda de Avia is a municipality in Galicia, in the province of Ourense.	42 19 12.81 N	8 09 53.03 W
+Cariño	Cariño is a municipality in the province A Coruña, Galicia, Spain.	43 43 58 N	7 52 39.76 W
+Carreira, Ribeira	San Paio de Carreira is a parish of Ribeira, Galicia	42 32 55.84 N	9 00 24.53 W
+Cartelle	Cartelle is a municipality in Galicia, in the province of Ourense.	42 15 00.44 N	8 04 17.46 W
+Casa Buonarroti (Florence)	Casa Buonarroti è un museo di Firenze	43 46 11.64 N	11 15 49 E
+Casa de las Carnicerías, León	The Casa de las Carnicerías (butcher's shops), a monument declared as a Bien de Interés Cultural in 1992, is located at San Martín square, León (Spain).	42 35 48.84 N	5 34 04.4 W
+Casa del esquileo, Cabanillas del Monte	The casa del esquileo (shearing shed) is a monument placed at Cabanillas del Monte, Torrecaballeros, Segovia (Spain).	40 58 36 N	4 01 54 W
+Casa Milà	Also known as 'La Pedrera', due to its look.	41 23 42.65 N	2 09 42.37 E
+Castel del Monte	Castel del Monte is a castle in Apulia, in Italy.	41 05 05.28 N	16 16 15.57 E
+Castellazzo Bormida	Castellazzo Bormida is a comune (municipality) in the Province of Alessandria in the Italian region Piedmont	44 50 46 N	8 34 42 E
+Castello di Duino	Il castello di Duino è un castello situato nel comune di Duino-Aurisina, in provincia di Trieste, Italia.	45 46 18.39 N	13 36 14.3 E
+Castello di Miramare	Miramare is a castle near Trieste.	45 42 09 N	13 42 45 E
+Castello di San Giusto	The statues Micheze and Jacheze in the entrance hall of Castello di San Giusto	45 38 49.99 N	13 46 23.62 E
+Castello Sforzesco (Milan)	The "Castello Sforzesco" is a castle and a museum in Milan, Italy.	45 28 11.4 N	9 10 46.2 E
+Castelo da Rocha Forte		42 51 42.29 N	8 34 29.38 W
+Castelo de Castro Marim		37 13 07.43 N	7 26 29.69 W
+Castelo de Maceda		42 16 13.92 N	7 39 32.36 W
+Castelo de Monforte de Lemos		42 31 26.71 N	7 30 38.86 W
+Castelo de Monterreal		42 07 29.82 N	8 50 59.18 W
+Castelo de Pambre		42 51 34.87 N	7 56 53.7 W
+Castelo de Ribadavia		42 17 12.3 N	8 08 37.49 W
+Castelo de San Felipe		43 27 52.83 N	8 16 52.45 W
+Castelo de Santa Cruz		43 20 54.08 N	8 21 00.64 W
+Castelo de Santo Antón		43 21 56.6 N	8 23 16.12 W
+Castelo de Sobroso	The Sobroso Castle is a castle located in Vilasobroso- Mondariz, Provincia of Pontevedra, Galicia (Spain).	42 12 17.3 N	8 27 20.51 W
+Castelo de Soutomaior		42 19 46.77 N	8 34 05.54 W
+Castelo de Vilalba		43 17 52.79 N	7 40 56.44 W
+Castelo de Vilamarín		42 27 02.87 N	7 54 02.26 W
+Castiñeiras, Ribeira		42 31 57.33 N	8 59 44.67 W
+Castrelo de Miño	Castrelo de Miño is a municipality in Galicia, in the province of Ourense.	42 17 49.63 N	8 04 02.63 W
+Castrelo do Val	Castrelo do Val is a municipality in Galicia, in the province of Ourense.	41 59 26.72 N	7 25 25.2 W
+Castro Caldelas	Castro Caldelas is a municipality in Galicia, in the province of Ourense.	42 22 32.63 N	7 24 54 W
+Castro de Baroña		42 41 40.91 N	9 01 54.91 W
+Castro de Rei		43 12 32.15 N	7 23 58.38 W
+Catacaos		5 16 00 S	80 41 00 W
+Catedral de Barcelona		41 23 02.07 N	2 10 35.19 E
+Catedral de Santiago de Compostela	Santiago de Compostela Cathedral is a Roman Catholic church in the city of the same name. It is the reputed burial-place of Saint James the Greater and the destination of the Way of St. James.	42 52 51.27 N	8 32 42.16 W
+Cathedral of Justo	The Cathedral of Justo is being built by Justo Gallego in Mejorada del Campo (Community of Madrid, Spain).	40 23 38.88 N	3 29 17.99 W
+Cathédrale Notre-Dame de Strasbourg		48 34 55 N	7 45 03 E
+Catoira	Catoira is a municipality in Galicia, Spain in the province of Pontevedra.	42 39 54.98 N	8 43 57.93 W
+Cedeira	Cedeira is a municipality in the province A Coruña, Galicia, Spain.	43 39 39.53 N	8 03 10.41 W
+Celanova	Celanova is a municipality in Galicia, in the province of Ourense.	42 09 07.02 N	7 57 24.65 W
+Cenlle	Cenlle is a municipality in Galicia, in the province of Ourense.	42 20 36.87 N	8 05 16.17 W
+Central Park		40 46 55.2 N	73 57 57.6 W
+Cesantes, Redondela		42 18 33.05 N	8 36 44.72 W
+Chantada		42 36 27.15 N	7 46 09.2 W
+Chapela, Redondela		42 15 53.95 N	8 40 22.72 W
+Chapelle de Languidou	Chapel in Plovan / Bretagne	47 54 49.13 N	4 21 09.72 W
+Chapelle Notre-Dame du Verger	Chapelle Notre-Dame du Verger dans l'anse du Verger à Cancale (Ille-et-Vilaine)	48 41 37 N	1 52 51 W
+Château d'Angers		47 28 11.67 N	0 33 33.61 W
+Château de Bugarach		42 52 36.16 N	2 21 05.15 E
+Château de Couiza		42 56 42.68 N	2 15 14.11 E
+Chiesa di Sant'Antonio in Caggiano	Church of Saint Anthony in Caggiano.	40 34 04.13 N	15 29 39.47 E
+Chioggia	Chioggia is a town in Veneto in Italy.	45 13 04.23 N	12 16 36.76 E
+Chroniques de Jérusalem	Jerusalem Mount of Olives Santa Marta Passionists church.	31 46 15.83 N	35 15 08.48 E
+Church of Adelboden	The gothic village church Adelboden was built in the 15th century	46 29 34.1 N	7 33 32.4 E
+Church of Saints Apostles Peter and Paul in Vilnius		54 41 38.82 N	25 18 22.69 E
+Church of St. Johns in Vilnius	Organ	54 40 57.5 N	25 17 19.22 E
+Church of São Vítor (Braga)	Igreja de São Victor em Braga	41 33 09.95 N	8 24 47.49 W
+Château de Malmaison	Château de Malmaison was the place of residence of Joséphine de Beauharnais and Napoleon Bonaparte	48 52 15 N	2 10 01 E
+Château de Puivert		42 55 16.21 N	2 03 17.82 E
+Cinque Terre	The Cinque Terre are five coastal villages in the province of La Spezia, Italy.	44 06 37.74 N	9 44 31.35 E
+Collingwood Monument	A monument to Admiral Collingwood (1748-1810) was erected in Tynemouth, North East England, in 1845.	55 00 52.96 N	1 25 12.14 W
+Collégiale Saint-Florent de Niederhaslach		48 32 35 N	7 20 29 E
+Collégiale Saint-Martin de Colmar		48 04 38.5 N	7 21 29 E
+Collégiale Saint-Thiébaut de Thann		47 48 40 N	7 06 06 E
+Colonia-Haus	The Colonia-Haus is a 45-storey, 147 m skyscraper completed in 1973 in the Riehl district of Cologne, Germany.	50 57 38 N	6 58 55 E
+Comacchio	Comacchio is a town in Emilia Romagna in Italy.	44 41 31.74 N	12 10 55.95 E
+Concatedral de Santa María de Guadalajara		40 38 04.72 N	3 09 45.15 W
+Corrubedo, Ribeira		42 34 21.64 N	9 04 22.77 W
+Cortegada	Cortegada is a municipality in Galicia, in the province of Ourense.	42 12 24.86 N	8 10 01.06 W
+Coulée verte René-Dumont	The Promenade plantée is an elevated park in the 12th arrondissement of Paris, France.	48 50 32 N	2 23 15 E
+Couvent de la Divine Providence de Saint-Jean-de-Bassel		48 48 12.12 N	6 59 32.06 E
+Crecente	Crecente is a municipality in Galicia, in the province of Pontevedra.	42 09 07.02 N	8 13 22.52 W
+Cualedro		41 59 18.46 N	7 35 40.71 W
+Culleredo	Culleredo is a municipality in the province A Coruña, Galicia, Spain.	43 17 31.02 N	8 23 08.99 W
+Curtis Hall Arboretum		40 04 42 N	75 07 44 W
+Córdoba (Argentina)	Intendancy square	31 24 00 S	64 11 00 W
+Dalhems kyrka	Die Kirche von Dalhem zählt zu den berühmtesten auf Gotland. Ihr Turm, der im 14. Jahrhundert angefügt wurde, gehört zu den höchsten der Landkirchen Gotlands.	57 33 08.7 N	18 32 03.2 E
+Dazaifu Tenman-gū		33 31 17.49 N	130 32 05.45 E
+Dent du Géant		45 51 43 N	6 57 06 E
+Detroit Institute of Arts	The Detroit Institute of Arts is a large art museum in Detroit, Michigan in the United States.	42 21 33.5 N	83 03 53.3 W
+Deutsches Museum Verkehrszentrum		48 07 57.85 N	11 32 40.69 E
+Deyrulzaferan		37 17 57.6 N	40 47 33.9 E
+Dorfkirche Zernikow		53 05 24.62 N	13 05 23.78 E
+Dozón		42 34 09.35 N	8 03 08.25 W
+Drexel University		39 57 14.68 N	75 11 12.76 W
+Duchesse Anne (voilier)		51 02 15.37 N	2 22 20.21 E
+Duino-Aurisina	English:	45 45 02.29 N	13 40 29.6 E
+Durban		29 53 00 S	31 03 00 E
+Dürrenstein (Südtirol)	The Dürrenstein is a mountain in the Dolomites in South Tyrol.	46 40 24 N	12 11 04 E
+Edinburgh Park & Ride network	The Park & Ride network serving Edinburgh, Scotland. Services run by Lothian Buses call at all the sites except Ferrytoll.	55 56 30.52 N	3 00 42.77 W
+Effnerplatz	The Effnerplatz is a square in the north of Munich, in the Borough Bogenhausen.	48 09 11.79 N	11 36 54.73 E
+Église Saint-Jean-Baptiste de Laure-Minervois		43 16 20.78 N	2 31 12.11 E
+Église Saint-Martin de Chambonas		44 25 02.45 N	4 07 43.97 E
+Eglise Saint-Pierre des Cuisines		43 36 15.49 N	1 26 08.26 E
+Église Saint-Vincent-de-Paul (Paris)	Saint-Vincent-de-Paul is a church in Paris near the Gare du Nord	48 52 43.7 N	2 21 06.6 E
+Empúries	Empúries is a town in the Mediterranean coast of the Catalan comarca of Empordà. It was founded by the ancient Greeks with the name of Ἐμπόριον (Emporion — "market").	42 08 20.29 N	3 07 11.19 E
+Erica, Victoria	Erica, Victoria	37 59 00 S	146 22 00 E
+Erlöserkirche (Bad Homburg)	The Church of the Redeemer is a protestant church in Bad Homburg, Germany.	50 13 35.5 N	8 36 42 E
+Esgos		42 19 29.71 N	7 41 45.94 W
+Eurockéennes 2015		47 41 08.79 N	6 48 30.36 E
+European Parliament		48 35 51.82 N	7 46 09.82 E
+Fangelsbachfriedhof	The Fangelsbachfriedhof is one of the most important historical cemeteries in Stuttgart.	48 45 56 N	9 10 28 E
+Feldkommandostelle Hegewald (East Prussia)		54 08 05.54 N	21 58 36.02 E
+Fene	Fene is a municipality in the province A Coruña, Galicia, Spain.	43 27 40.11 N	8 11 28.2 W
+Ferrol		43 29 21.46 N	8 13 29.94 W
+Ferrytoll Park & Ride	Ferrytoll Park & Ride is a bus/car interchange in Fife, Scotland, at the northern end of the Forth road crossing.	56 01 21.47 N	3 24 22.97 W
+Fieschergletscher		46 30 07.88 N	8 08 30.59 E
+Fiesole (area archeologica)		43 48 29.05 N	11 17 39.19 E
+Fish Creek, Victoria	Fish Creek, Victoria	38 41 00 S	146 05 00 E
+Flaucher	Flaucher is an area in the south of Munich on the left and right hand side of the Isar (district: Sendling and Thalkirchen).	48 06 27 N	11 33 27 E
+Fort de Bessoncourt		47 38 58.41 N	6 55 37.74 E
+Fort de la Miotte		47 38 53.29 N	6 52 30.33 E
+Fort des Basses Perches		47 37 34.05 N	6 52 06.81 E
+Fort du Bois d'Oye		47 34 27.7 N	6 50 36.55 E
+Fort Ross	Fort Ross, a former Russian fur trade outpost, located on the coast of Northern California (United States).	38 30 51.35 N	123 14 36.88 W
+Fortaleza da Nogueirosa		43 23 29.12 N	8 08 09.12 W
+Fortaleza de San Paio de Narla		43 00 25.83 N	7 49 14 W
+Forte di Gavi	Il Forte di Gavi è una fortezza storica costruita su un preesistente castello di origine medioevale.	44 41 27.95 N	8 48 15.55 E
+Fortezza del Priamar	La fortezza del Priamar è un antico insediamento storico presente nella città ligure di Savona, Italia.	44 18 16.29 N	8 29 03.44 E
+Forêt domaniale de Sète	The National Forest of Sète in the commune of Sète, Hérault, France.	43 24 18.74 N	3 40 13.74 E
+Fosse De Sessevalle		50 22 11.03 N	3 15 41.09 E
+Four solaire d'Odeillo	The "Centre du Four Solaire Félix Trombe" is located in Odeillo, France.	42 29 37 N	2 01 45 E
+Francelos, Ribadavia		42 16 35.51 N	8 09 34.87 W
+Franciscan Monastery in Katowice Panewniki	Neo-Romanesque monastery of the Franciscans in Katowice Panewniki in Poland from the early XX century.	50 13 37 N	18 57 45 E
+Pfarrkirche St. Bartholomäus in Friesach		46 57 04.28 N	14 24 18.19 E
+Fubine	Fubine è un comune in provincia di Alessandria, Piemonte, Italia.	44 57 55.35 N	8 25 32.75 E
+Fuzhou	Fuzhou, also known as Foochow, is a city in China.	26 04 16 N	119 18 13 E
+Gandino		45 48 42 N	9 54 11 E
+Gardens of Nymphenburg Palace	Der Nymphenburger Schlosspark ist eines der größten und bedeutendsten Gartenkunstwerke Deutschlands.	48 09 29 N	11 30 13 E
+Garmischer Straße	The Garmischer Straße is a street in Munich, part of the Mittlerer Ring around the city centre.	48 07 28.03 N	11 31 14.51 E
+Garten des Himmlischen Friedens	The Garten des Himmlischen Friedens (lit. Garden of Heavenly Peace) is a small walled Chinese garden in the Bethmannpark in Frankfurt-Nordend	50 07 07.57 N	8 41 26.52 E
+Gavi	Gavi is a town in Piemonte in Italy.	44 41 19.35 N	8 48 10.64 E
+Gedankengang Offenbach	This is part of a series of tunnels in Offenbach that have been redesigned.	50 05 58.64 N	8 45 49.92 E
+Gent-Wevelgem 2014		50 48 29.25 N	3 10 49.47 E
+Georg-Brauchle-Ring	The Georg-Brauchle-Ring is a street in Munich.	48 10 34.46 N	11 32 35.48 E
+Gernikako Arbola	The Gernika oak where the lords of Biscay (including several kings of Castile and Spain) came to take the oath of respect to the basques Fueros (Rules and Rights).	43 18 53.44 N	2 40 47.92 W
+Giardino dei Semplici di Firenze	The Orto Botanico di Firenze (2.3 hectares), also known as the Giardino dei Semplici, is a botanical garden maintained by the University of Florence.	43 46 45 N	11 15 39 E
+Giurtelecu Şimleului	Giurtelecu Şimleului is a settlement in Romania.	47 18 N	22 48 E
+Goethedenkmal (Wien)	The Goethe monument at the Opernring in Vienna by Edmund Hellmer	48 12 12.07 N	16 21 57.73 E
+Gogar Tram Depot		55 56 22.27 N	3 19 36.44 W
+Gorle		45 42 14 N	9 43 08 E
+Government House, Jersey		49 11 41.44 N	2 05 39.78 W
+Gradara	Gradara is a town in Marche, Italy.	43 56 15.75 N	12 45 59.24 E
+Granollers	Granollers is a city near Barcelona, in Catalonia, Spain.	41 32 35.1 N	2 12 59.63 E
+Gråmanstorps kyrka		56 08 59.33 N	13 06 00.4 E
+Guaricano	Barrio of Santo Domingo (Dominican Republic), Genoese mission	18 32 01.81 N	69 55 58.57 W
+Gut Böckel	Böckel Castle in Rödinghausen, District of Herford, North Rhine-Westphalia, Germany.	52 13 29.1 N	8 31 02.98 E
+Gymnasium Koblenzer Straße	The Gymnasium Koblenzer Straße, also known as Kobi, is a German grammar school in Urdenbach, an urban borough of Düsseldorf.	51 08 58.67 N	6 53 08.95 E
+Göltzschtalbrücke		50 37 21.29 N	12 14 37.46 E
+Hamburg	Hamburg is a City-State in the North of Germany and one of the biggest seaports in Europe.	53 34 07 N	10 02 19 E
+Hamburger Rathaus		53 33 01 N	9 59 32 E
+Hansestaden Visby	The Hanseatic town Visby was founded in the 10th century, on the then independent Baltic Sea island of Gotland.	57 38 20 N	18 17 40 E
+Haus Werburg	Haus Werburg is a small water castle in Spenge, Kreis Herford.	52 08 30.78 N	8 28 33.66 E
+Hazmburk	Hazmburk is a hill with castle in České středohoří in Czech Republic.	50 26 03 N	14 00 52 E
+Heckenstallerstraße	The Heckenstallerstraße is a street in Munich, part of the Mittlerer Ring around the city centre.	48 06 35.77 N	11 31 42 E
+Heiligenhäuschen Neun Morgen, Burggrumbach		49 52 42.52 N	10 01 26.96 E
+Hellig Kors Kirke	Hellig Kors Kirke is a church on Nørrebro in Copenhagen, Denmark.	55 41 15.72 N	12 33 05.04 E
+Henninger-Turm	The 120-m-high Henninger Turm is located in Frankfurt-Sachsenhausen in Germany.	50 05 50.16 N	8 41 36.77 E
+Herford	Herford is a city in North Rhine-Westphalia, Germany.	52 06 57.81 N	8 40 12.11 E
+HMS Otus	The HMS Otus is a british Oberon class submarine. It serves today as a museum Sassnitz harbour.	54 30 43.13 N	13 38 29.79 E
+Holy Trinity Cathedral in Odessa		46 28 34.36 N	30 44 18.43 E
+Hoppenlaufriedhof	The Hoppenlaufriedhof is a cemetery in Stuttgart.	48 46 54 N	9 10 05 E
+Horyuji	Hōryū-ji (法隆寺, "Temple of the Flourishing Law") is a Buddhist temple in Ikaruga, Nara Prefecture, Japan.	34 36 53.06 N	135 44 03.02 E
+Hospitalkirche (Stuttgart)		48 46 40 N	9 10 22 E
+Hôtel du Gouverneur, Belfort		47 38 16.16 N	6 51 49.16 E
+Igreja de São Martinho de Aldoar		41 10 14.58 N	8 40 13.83 W
+Igrexa de San Pedro de Vilanova de Dozón	The romanic parochial Church of San Pedro of Dozón	42 35 06.77 N	8 01 27.02 W
+Igrexa de Santa María de Cambre		43 17 32.03 N	8 20 34.4 W
+Igrexa de Santo Antolín de Toques		42 58 41.36 N	7 58 59.23 W
+Illa de Cortegada		42 37 05.87 N	8 47 02.7 W
+Iloilo City	The City of Iloilo is the capital city of the Provinces of the Philippines of Iloilo.	10 41 24 N	122 33 00 E
+Im Klosterhof Nr 4, Kennelbach Vbg, Aufbahrungshalle		47 28 49.67 N	9 45 59.27 E
+Info:Kusterdingen	Kusterdingen is a municipality situated between Tübingen and Reutlingen in Baden-Württemberg in Germany.	48 31 20.28 N	9 07 15.24 E
+Info:Mössingen	Mössingen is a municipality circa 15km south of Tübingen in Baden-Württemberg in Germany.	48 24 23 N	9 03 27 E
+Institut de théologie orthodoxe Saint-Serge		48 52 59.98 N	2 23 01.23 E
+Isarring	The Isarring is a street in Munich, part of the Mittlerer Ring around the city centre.	48 09 36.65 N	11 36 03.89 E
+Isla San Carlos	Peninsula of San Carlos, commonly known as San Carlos Island, part of Venezuela, is located north of the island of Toas, between the Gulf of Venezuela and Lake Maracaibo.	10 59 42.73 N	71 36 43.16 W
+Ivrea	Ivrea is a town in Piemonte in Italy.	45 27 50.4 N	7 52 42.96 E
+Jagdschloss Wermsdorf		51 16 59.52 N	12 56 21.85 E
+Jesuitenkirche (Wien)	The Jesuit church is a prominent church in Vienna, Austria.	48 12 32.95 N	16 22 39.48 E
+Jin Mao Tower	Jin Mao Building	31 14 14 N	121 30 05 E
+Johannesburg	Johannesburg is the largest city in South Africa.	26 12 16 S	28 02 44 E
+Jubiläumssäule		48 46 42.85 N	9 10 47.53 E
+Jumkils kyrka	Jumkils kyrka tillhör Bälingebygdens församling, Upplands västra kontrakt, Uppsala stift / Diocese of Uppsala.	59 56 33.2 N	17 25 23.7 E
+Kaaba		21 25 21.11 N	39 49 34.41 E
+Kagawa prefecture	Kagawa Prefecture (香川県, Kagawa-ken?) is a prefecture of Japan located on Shikoku island. The capital is Takamatsu.	34 20 24.4 N	134 02 35.8 E
+Kansai International Airport	Kansai International Airport, is an international airport located on an artificial island in the middle of Osaka Bay, off the shore of Sennan district of Osaka, Japan.	34 26 03 N	135 13 58 E
+Karlsfried	Karlsfried Castle is situated nearby the town of Zittau in Sachsen, Germany.	50 50 05.05 N	14 47 32.29 E
+Katharinenhospital Stuttgart		48 48 01.87 N	9 12 21.6 E
+Kennesaw State Soccer Stadium	New KSU Stadium is a new stadium near Kennesaw, Georgia that is currently being constructed.	34 01 46.43 N	84 34 03.63 W
+Kiel	Kiel is the Capital city and most populous city of the northern German state Schleswig-Holstein.	54 19 31 N	10 08 26 E
+Kleinmarkthalle Frankfurt		50 06 45 N	8 41 01 E
+Kloster Ettal	The monastery of Ettal is a Benedictine monastery in Bavaria/Germany near Oberammergau.	47 34 09.33 N	11 05 40.42 E
+Kotohira Gu	Kotohira Gu in Kotohira, Kagawa prefecture, Japan.	34 11 02.2 N	133 48 34 E
+Kreis Herford		52 06 57.54 N	8 39 40.42 E
+Kreis Minden-Lübbecke	Der Kreis Minden-Lübbecke ist ein Landkreis im Osten des Landes Nordrhein-Westfalen mit Sitz in Minden.	52 16 53.48 N	8 54 41.71 E
+Kreuzschlepper Am Weiher 1, Holzhausen		50 07 06.2 N	10 11 07.12 E
+Kronprinzenpalais (Stuttgart)		48 46 41.56 N	9 10 39.88 E
+Krumbach (Schwaben)	Krumbach (Schwaben) ist eine Stadt im Landkreis Günzburg, Regierungsbezirk Schwaben, Bayern.	48 14 35 N	10 21 48 E
+Krummesse	Krummesse is a village in Schleswig-Holstein, Germany, which partly belongs to Kreis Herzogtum Lauenburg and partly to Lübeck.	53 46 45 N	10 38 30 E
+Kuala Lumpur		3 08 08.5 N	101 41 16.8 E
+Kunsthalle Bremen		53 04 22 N	8 48 49 E
+Kuressaare		58 09 00 N	22 16 48 E
+Kusterdingen		48 31 20.28 N	9 07 15.24 E
+Lac Blanc (Orbey)	Dans le massif des Vosges, près d'Orbey.	48 07 31.32 N	7 05 34.95 E
+Lac de Serre-Ponçon	Le Lac de Serre-Ponçon, vallé de l'Ubaye, Hautes-Alpes, France	44 30 33.26 N	6 22 10.8 E
+Lalín	Lalín is a municipality in Galicia, Spain in the province of Pontevedra.	42 39 36.8 N	8 06 43.31 W
+Langes Tannen	The domain Langes Tannen now belongs to the town of Uetersen.	53 41 32.67 N	9 40 28.6 E
+Large Hadron Collider		46 16 17 N	6 03 48.5 E
+Larouco	Larouco is a municipality in Galicia, in the province of Ourense.	42 20 48.74 N	7 09 37.22 W
+Laza	Laza is a municipality in Galicia, in the province of Ourense.	42 03 36.69 N	7 27 37.14 W
+Le Crozet (Loire)	Le Crozet est une commune française, située dans le département de la Loire et la région Rhône-Alpes.	46 10 11 N	3 51 25 E
+Le Sauze-du-Lac	Le Sauze-du-Lac est un petit village de les Hautes-Alpes, prés du lac de Serre-Ponçon.	44 28 42.94 N	6 18 52.35 E
+Leiro	Leiro is a municipality in Galicia, in the province of Ourense.	42 22 11.51 N	8 07 27.42 W
+Levanto	Levanto is a village in Liguria in Italy.	44 10 15.82 N	9 36 41.68 E
+Ligne Aubagne - Fuveau		43 23 41.38 N	5 33 59.44 E
+Lima		12 05 36 S	77 02 48 W
+Loro Parque	Puerto de la Cruz, Tenerife, Canarias, España	28 24 30.18 N	16 33 51.25 W
+Lothian Buses: Central garage	Central garage in Annandale Street, Broughton, is one of Lothian Buses' depot sites.	55 57 40.43 N	3 11 16.73 W
+Luise-Kiesselbach-Platz	The Luise-Kiesselbach-Platz is a square in the southwest of Munich.	48 06 44.17 N	11 31 03.27 E
+Lunds domkyrka	Lunds domkyrka or Lund Cathedral is the cathedral of Lund in Skåne in southern Sweden.	55 42 14.59 N	13 11 36.91 E
+LWL-Freilichtmuseum Detmold	The LWL-Freilichtmuseum Detmold (earlier name: Westfälisches Freilichtmuseum Detmold) is a museum for folklife studies in the town of Detmold, Germany.	51 55 25 N	8 52 12 E
+Madone		45 39 00 N	9 32 53 E
+Magasin-caverne du Salbert		47 39 20.34 N	6 49 22.79 E
+Magazzini del Cotone di Genova	I Magazzini del Cotone sono una delle principali strutture del porto antico di Genova.	44 24 29.75 N	8 55 16.68 E
+Mahabodhi Temple	The Mahabodhi Temple is a Buddhist temple in Bodh Gaya, the location where Siddhartha Gautama, the Buddha, attained enlightenment.	24 41 46 N	84 59 29 E
+Maisons de la rue Jeanne-Mance		45 30 31.9 N	73 34 11.02 W
+Manneken Pis van Brussel	Manneken Pis in Brussels	50 50 42 N	4 21 00 E
+Manzaneda	Manzaneda is a municipality in Galicia, in the province of Ourense.	42 18 35.34 N	7 13 58.01 W
+Mary's Tomb	'egg' (ornament hung on oil lamp chains) with winged seraphim. Armenian artwork	31 46 48.5 N	35 14 21.41 E
+Marín		42 23 31.28 N	8 42 16.58 W
+Maside	Maside is a municipality in Galicia, in the province of Ourense.	42 24 44.75 N	8 01 31.85 W
+Matitone (Genova)	Il Matitone è un grattacielo di Genova dalla struttura a forma di lapis. È situato nella zona portuale di San Benigno, a breve distanza dalla torre della Lanterna.	44 24 40.59 N	8 54 25.07 E
+Maximiliansbrücke in München		48 08 12.42 N	11 35 31.45 E
+Meaño	Meaño is a municipality in Galicia, Spain in the province of Pontevedra.	42 26 31.95 N	8 46 46.02 W
+Meis	Meis is a municipality in Galicia, Spain in the province of Pontevedra.	42 30 49.01 N	8 41 27.14 W
+Melón	Melón is a municipality in Galicia, in the province of Ourense.	42 15 26.97 N	8 13 01.51 W
+Mii-dera	Mii-dera 三井寺, formally Onjōji 園城寺, is a Tendai Buddhist temple in the city of Otsu, Shiga Prefecture, Japan.	35 00 48.09 N	135 51 10.26 E
+Millennium Town Park	The Millennium Town Park is a public park in Saint Helier, Jersey.	49 11 15.01 N	2 06 06.95 W
+Minden	Minden is a German city in North Rhine-Westphalia.	52 17 20.18 N	8 55 04.19 E
+Mindener Dom	Cathedral in Minden, District of Minden-Lübbecke, North Rhine-Westphalia, Germany.	52 17 19.85 N	8 55 09.94 E
+Mindener Kreisbahnen	Kreisbahnen Minden, ein Unternehmen aus dem 19. Jahrhundert, das in Abwandlungen noch heute besteht.	52 18 01.14 N	8 54 50.98 E
+Miquel Marti i Pol.jpg	Monument al Llibre, Saltamartí	41 23 21.34 N	2 10 05.05 E
+Mittagskogel	Mittagskogel is a peak in the Karawanken mountain chain in Carinthia / Austria / EU.	46 30 26.54 N	13 57 08.1 E
+Moaña	Moaña is a municipality in Galicia, Spain in the province of Pontevedra.	42 17 05.52 N	8 44 57.56 W
+Moe, Victoria	Moe, Victoria	38 10 20 S	146 16 04 E
+Molino Stucky	Il Molino Stucky è uno storico edificio di Venezia. È un esempio di architettura industriale neogotica.	45 25 41.55 N	12 19 11.95 E
+Mollet del Vallès	Mollet del Vallès is a village in the comarca of Vallès Oriental (Catalonia, Spain).	41 32 35.1 N	2 12 59.63 E
+Monastery of San Paio de Diomondi		42 36 13.6 N	7 42 34.1 W
+Monforte de Lemos		42 31 19.98 N	7 30 46.55 W
+Monte Amiata	Il Monte Amiata è un monte situato nella Toscana.	42 54 00 N	11 38 00 E
+Monte Musinè	el Monte Musinè es una cima de los Alpes Grayos, en Italia.	45 06 50 N	7 27 16 E
+Monterrei	Monterrei is a municipality in Galicia, in the province of Ourense.	41 56 51.19 N	7 26 58.52 W
+Montevideo		34 52 01 S	56 10 00 W
+Montsec d'Ares	El Montsec d'Ares és el sector central de la Serra del Montsec, entre els congostos deTerradets a l'est i el de Mont-rebei a l'oest	42 02 27.96 N	0 47 33.68 E
+Monument de Joseph Sec	Monument Joseph Sec, 8 avenue Pasteur, Aix-en-Provence, France.	43 31 59.44 N	5 26 46.71 E
+Monument international de la Réformation		46 12 00.78 N	6 08 45.19 E
+Mos	Mos is a municipality in Galicia, Spain in the province of Pontevedra.	42 11 39.08 N	8 39 11.18 W
+Mosteiro de San Clodio de Leiro		42 22 02.61 N	8 06 54.12 W
+Mosteiro de San Salvador de Celanova		42 09 06.55 N	7 57 24.85 W
+Mosteiro de Santa María de Aciveiro		42 37 03 N	8 18 06 W
+Mońki	Railway station	53 24 00 N	22 47 00 E
+Mugardos	Mugardos is a municipality in the province A Coruña, Galicia, Spain.	43 27 43.7 N	8 15 12.52 W
+Muros		42 46 28.69 N	9 03 23.75 W
+Murray House		22 13 05.15 N	114 12 34.96 E
+Murviel-lès-Béziers		43 26 29 N	3 08 42 E
+Museo Civico d'Arte Antica di Torino	Il Museo Civico d'Arte Antica è un polo museale situato a Torino presso Palazzo Madama.	45 04 15.95 N	7 41 07.72 E
+Museo della Storia del Genoa		44 24 37.8 N	8 56 11.39 E
+Museo Regionale della Fauna Alpina - Alpenfaunamuseum "Beck-Peccoz"	Un museo sulla fauna alpina situato a Gressoney-Saint-Jean, in Valle d'Aosta, Italia.	45 46 35.57 N	7 49 36.84 E
+Museum für Moderne Kunst	The Museum für Moderne Kunst (MMK) is an art museum in Frankfurt am Main.	50 06 42.56 N	8 41 03.86 E
+Möja kyrka		59 24 18.8 N	18 52 53 E
+Mössingen		48 24 23 N	9 03 27 E
+Nagaoka Tenman-gū	日本語: 長岡天満宮, 京都府長岡京市。	34 55 22.2 N	135 41 10.8 E
+Narón	Narón is a municipality in the province A Coruña, Galicia, Spain.	43 32 14.91 N	8 10 53.28 W
+Neda	Neda is a municipality in the province A Coruña, Galicia, Spain.	43 29 58.67 N	8 09 21.51 W
+Neues Rathaus München		48 08 16.07 N	11 34 33.35 E
+Neues Schloss, Stuttgart	The south front parallels the Planie and the Alte Schloss.	48 46 41 N	9 10 55 E
+New Mosque in Istanbul	New Mosque (Yeni Cami) in Istanbul	41 01 01.05 N	28 58 19.2 E
+Niujie Mosque	The Niujie Mosque (Chinese: 牛街清真寺; pinyin: niújiē qīngzhēnsì) is the oldest mosque in Beijing, China. It was built in 996 and completely rebuilt under the Kangxi Emperor (1622-1722).	39 53 04 N	116 21 29 E
+Nizza-Ufer	The Nizza bank is a park with mild microclimate at the Main river bank in Frankfurt am Main. The Park was constructed in 1860.	50 06 15.68 N	8 40 14.37 E
+Noorderplantsoen	The Noorderplantsoen is a park in the Dutch city of Groningen.	53 13 25 N	6 33 20 E
+Nullamunjie Olive Grove, Victoria	Nullamunjie olive groves are situated in the mountains of eastern Victoria, Australia on the slopes of Mount Stawell and near the banks of the Tambo River.	37 11 05 S	147 43 58 E
+O Barco de Valdeorras		42 24 38.82 N	6 58 33.51 W
+O Bolo	O Bolo is a municipality in Galicia, in the province of Ourense.	42 18 27.11 N	7 05 52.28 W
+O Carballiño		42 25 53.18 N	8 04 38.48 W
+O Grove		42 29 34.29 N	8 52 04.9 W
+O Pereiro de Aguiar	O Pereiro de Aguiar is a municipality in Galicia, in the province of Ourense.	42 20 47.83 N	7 48 06.62 W
+O Porriño	O Porriño is a municipality in Galicia, Spain in the province of Pontevedra.	42 09 41.84 N	8 37 15 W
+O Rosal	O Rosal is a municipality in Galicia, Spain in the province of Pontevedra.	41 56 07.29 N	8 50 05.63 W
+O Ézaro, Dumbría		42 54 38.2 N	9 07 54.11 W
+Obermillstatt		46 48 36.91 N	13 35 29.41 E
+Obervellach		46 55 55.76 N	13 12 06.68 E
+Ocean Park, Hong Kong		22 14 45.1 N	114 10 33.3 E
+Ohr Somayach Synagogue	Ohr Somayach Synagogue, the main synagogue in Odessa, Ukraine	46 28 40.55 N	30 44 22.13 E
+Oia	Oia is a municipality in Galicia, Spain in the province of Pontevedra.	42 00 06.45 N	8 52 30.54 W
+Oleiros	Oleiros is a municipality in the province A Coruña, Galicia, Spain.	43 19 57.16 N	8 18 54.38 W
+Oleiros, Ribeira		42 36 11.29 N	9 00 20.52 W
+Olgastraße (Stuttgart)		48 46 04.17 N	9 10 44.23 E
+Orangerie (Neustrelitz)	Die Orangerie in Neustrelitz wurde bereits 1755 erbaut und erfuhr 1840 bis 1842 einen grundlegenden Umbau durch Friedrich Wilhelm Buttel.	53 21 40 N	13 03 27 E
+Organización Médica Colegial de España	Spanish Medical Colleges Organization	40 24 57.24 N	3 41 49.49 W
+Ortigueira	Ortigueira is a municipality in the province A Coruña, Galicia, Spain.	43 41 12.94 N	7 51 10.47 W
+Os Blancos	Os Blancos is a municipality in Galicia, in the province of Ourense.	41 59 50.61 N	7 45 12.35 W
+Ouaisné		49 10 45.75 N	2 11 10.77 W
+Oza-Cesuras	Oza-Cesuras, municipality in the province of A Coruña, in Galicia (Spain).	43 16 44.24 N	8 12 55.95 W
+Ozurgeti	Ozurgeti is a town and the regional administrative centre of Western Georgian province of Guria, former Macharadze or Makharadze (named in honor of Filipp Makaradze).	41 55 26.26 N	42 00 33.84 E
+Oímbra		41 53 07.94 N	7 28 19.78 W
+Palacete de Belomonte	Palacete de Belomonte / Palácio de Belomonte / Casa dos Pacheco Pereira. Em Portugal, Porto, Porto, São Nicolau.	41 08 33.18 N	8 36 58.35 W
+Palais du parlement du Dauphiné		45 11 35.97 N	5 43 42.86 E
+Palais Garnier	The Palais Garnier, also known as Opéra Garnier or Opéra national de Paris is an opera house situated at the northern end of the avenue de l'Opera, in Paris.	48 52 19 N	2 19 54 E
+Palmenhaus, Vienna	Vienna's Palmenhaus ('palm house', a Jugendstil greenhouse built in 1901) is a building in Vienna's 1st district, beneath 'Burggarten' and Hofburg.	48 12 18 N	16 22 01 E
+Palácio de Estói		37 05 47.79 N	7 53 44.05 W
+Palácio Nacional da Pena		38 47 15.24 N	9 23 25.75 W
+Palácio Nacional de Mafra	O Palácio Nacional de Mafra é um palácio e mosteiro monumental de estilo neoclássico localizado em Mafra (Portugal) a poucos mais de 50 quilómetros de Lisboa.	38 56 12 N	9 19 35 W
+Pamukkale	Pamukkale is a natural site and attraction and a UNESCO World Heritage Site in south-western Turkey.	37 55 25 N	29 07 24 E
+Parc du Thabor		48 06 51 N	1 40 12 W
+Petuelpark		48 10 39.64 N	11 34 45.32 E
+Petuelring	The Petuelring is a street in Munich, part of the Mittlerer Ring around the city centre.	48 10 40.25 N	11 34 19 E
+Petueltunnel	The Petueltunnel is a tunnel that runs beneath the Petuelring between the Boroughs Milbertshofen-Am Hart and Schwabing-West in Munich.	48 10 39.9 N	11 34 37.48 E
+Philadelphia City Hall	Philadelphia City Hall is the seat of government for the city of Philadelphia, Pennsylvania.	39 57 08.28 N	75 09 48.96 W
+Piazza Corvetto (Genova)	Piazza Corvetto è una delle principali piazze di Genova	44 24 36.1 N	8 56 18.2 E
+Piazza della Vittoria (Genoa)	Piazza della Vittoria è una delle principali piazze di Genova.	44 24 11.12 N	8 56 42.45 E
+Piazza Navona	Piazza Navona is a square in Parione, the VI. Rione (district) from Rome / Italy / EU.	41 53 56.21 N	12 28 23.15 E
+Piazza Venezia	Piazza Venezia is Located in Rome.	41 53 47 N	12 28 57 E
+Pieve di San Giorgio di Valpolicella	The Pieve di San Giorgio di Valpolicella is a particularly large and elaborate Pieve (ancient church) of the city of Sant'Ambrogio di Valpolicella, Italy.	45 32 07 N	10 51 00 E
+Piode	Piode è un comune della Valsesia, in provincia di Vercelli, Piemonte, Italia.	45 46 09.98 N	8 02 57.28 E
+Piñor	Piñor is a municipality in Galicia, in the province of Ourense.	42 29 50.7 N	8 00 21.4 W
+Place royale du Peyrou		43 36 40 N	3 52 15 E
+Plaridel Airport		14 53 27.91 N	120 51 09.9 E
+Plaça Catalunya	Plaça Catalunya (or Plaza de Cataluña in spanish) is a large square in central Barcelona.	41 23 13.21 N	2 10 12.09 E
+Ponte de Rande		42 17 18.66 N	8 39 37.45 W
+Ponte Sant'Angelo (Rome)	The Ponte Sant'Angelo is a Roman bridge across the Tiber in Rome, Italy.	41 54 06.46 N	12 27 59.24 E
+Pontedeume		43 24 13.68 N	8 09 46.85 W
+Pontevedra		42 25 50.84 N	8 38 56.28 W
+Pordoi Pass	The Pordoi Pass is an Alpine pass in the Dolomites.	46 29 19.33 N	11 48 52.54 E
+Port of Kobe	Port of Kobe in Kobe, Hyōgo Prefecture, Japan	34 40 39.17 N	135 13 36.97 E
+Porta Pia		41 54 33 N	12 30 04 E
+Porta san Sebastiano		41 52 25 N	12 30 07 E
+Porta Soprana (Genova)	Porta Soprana a Genova.	44 24 19.76 N	8 56 05.6 E
+Porta Westfalica		52 14 22.66 N	8 55 14.31 E
+Porto antico di Genova		44 24 34.22 N	8 55 04.27 E
+Porto Azzurro		42 46 05.02 N	10 23 48.33 E
+Portor, Negreira		42 54 45.44 N	8 41 52.17 W
+Potemkin Stairs		46 29 18.75 N	30 44 31.18 E
+Praia de Cabanas		43 24 55.21 N	8 10 23.62 W
+Prinzenbau Stuttgart		48 46 38.55 N	9 10 40.96 E
+Puits Arthur-de-Buyer		47 40 37.23 N	6 36 51.29 E
+Punta Manara	Manara Bivouac	44 15 19.08 N	9 24 20.88 E
+Punxín	Punxín is a municipality in Galicia, in the province of Ourense.	42 22 06.15 N	8 00 03.17 W
+Quartier de Beaugrenelle		48 51 03.87 N	2 17 07.61 E
+Rairiz de Veiga		42 04 57.65 N	7 49 56.93 W
+Ravensberger Bahn	Die Ravensberger Bahn ist eine Eisenbahnstrecke von Bielefeld nach Rahden.	52 13 36.48 N	8 31 20.75 E
+Redondela	Redondela is a municipality in Galicia, Spain in the province of Pontevedra.	42 17 03 N	8 36 31.13 W
+Regattastrecke Oberschleißheim	Die Regattastrecke Oberschleißheim ist ein künstlicher, rechteckiger Grundwassersee im Norden von München, angelegt für die Olympischen Sommerspiele 1972.	48 14 33.67 N	11 30 54.38 E
+Reggia di Caserta	La Reggia di Caserta, Palazzo Reale, è stata la dimora della dinastia dei Borboni, sovrani del Regno delle due Sicilie. È situata a Caserta, in Campania (Italia).	41 04 26.27 N	14 19 36.92 E
+Rianxo	Rianxo is a port town in Galicia, Spain, in the province of A Coruña.	42 38 38.62 N	8 48 44.67 W
+Ribadavia		42 17 13.06 N	8 08 34.54 W
+Ribadumia	Ribadumia is a municipality in Galicia, Spain in the province of Pontevedra.	42 30 50.38 N	8 45 25.68 W
+Ribeira	Ribeira is a municipality in the province A Coruña, Galicia, Spain.	42 32 38.31 N	9 00 06.92 W
+Ribeira, Ribeira		42 33 16.32 N	8 59 27.37 W
+Ricetto di Candelo		45 32 46.68 N	8 06 48.96 E
+Rio Marina	Rio Marina is a village in Isola d'Elba Toscana in Italy	42 48 44.2 N	10 25 39.87 E
+Risiera di San Sabba	La Risiera di San Sabba è stato un campo di concentramento nazista, attivo negli ultimi anni della seconda guerra mondiale a Trieste, Italia.	45 37 26.09 N	13 47 22.1 E
+Riós	Riós is a municipality in Galicia, in the province of Ourense.	41 58 29.53 N	7 16 55.68 W
+Robben Island	Robben Island, Cape Town, South Africa	33 48 24.24 S	18 21 58.4 E
+Rocca Grimalda	Rocca Grimalda è un comune dell'Alto Monferrato, in provincia di Alessandria, Piemonte, Italia.	44 40 17.48 N	8 38 55.12 E
+Rodeiro	Rodeiro is a municipality in Galicia, Spain in the province of Pontevedra.	42 39 00.44 N	7 56 59.93 W
+Roman Theatre of Catania		37 30 10.4 N	15 05 00.9 E
+Roujan		43 30 32.5 N	3 17 15.15 E
+Río Tambre		42 54 20.32 N	8 41 43.21 W
+Sacrario Militare di Redipuglia		45 51 05.58 N	13 29 22.49 E
+Sada	Sada is a municipality in the province A Coruña, Galicia, Spain.	43 21 01.43 N	8 15 16.23 W
+Safranbolu	Safranbolu is a city and district of Karabük Province, Turkey. Safranbolu is one of the World Heritage sites in Turkey.	41 14 41 N	32 41 37 E
+Sagrada Família		41 24 12.82 N	2 10 27.64 E
+Saint-Michel de Nahuze	Prieuré du XIe siècle, situé sur la commune de Lagrasse (département de l'Aude), dont les ruines ont été inscrites comme monument historique	43 07 56.82 N	2 37 06.38 E
+Saint-Nazaire-de-Ladarez		43 30 37 N	3 04 36 E
+Salt Lake Temple	The Salt Lake Temple, the sixth temple built by the church overall, and the fourth operating temple, is the largest and best-known temple of The Church of Jesus Christ of Latter-day Saints.	40 46 14.45 N	111 53 31.18 W
+San Amaro	San Amaro is a municipality in Galicia, in the province of Ourense.	42 22 20.07 N	8 04 23.64 W
+San Clodio, Leiro		42 22 02.61 N	8 06 54.12 W
+San Cristovo de Cea	San Cristovo de Cea is a municipality in Galicia, in the province of Ourense.	42 28 33.22 N	7 59 07.24 W
+San Giorgio in Lemine	San Giorgio in Lemine is a church in the comune of Almenno San Salvatore, Bergamo, Lombardy, Italy	45 44 46 N	9 35 50 E
+San Sadurniño	San Sadurniño is a municipality of Spain in the province of A Coruña, in the autonomous community of Galicia.	43 33 44.93 N	8 03 17.21 W
+Sandiás	Sandiás is a municipality in Galicia, in the province of Ourense.	42 06 38.53 N	7 45 28.41 W
+Sankt Martini		53 04 30 N	8 48 15 E
+Sant'Anastasia	Sant'Anastasia è una chiesa di Roma.	41 53 17.6 N	12 29 03 E
+Santiago de Chile	Santiago is the capital of Chile, it is also the country's industrial and commercial center.	33 27 00 S	70 40 00 W
+Santiago de Compostela		42 52 50.24 N	8 32 39.96 W
+Sanxenxo		42 24 19.2 N	8 48 23.66 W
+Sarreaus		42 05 13.93 N	7 36 10.99 W
+Sarria		42 46 38.13 N	7 24 54.31 W
+Schallenberg		46 49 34 N	7 47 50 E
+Schenkendorfstraße	The Schenkendorfstraße is a street in Munich, part of the Mittlerer Ring around the city centre.	48 10 34.21 N	11 35 29.04 E
+Schloss Eutin	The Castle of Eutin is located in Eutin in Schleswig-Holstein. It was built onto the foundations of a medieval castle.	54 08 15.75 N	10 37 13.22 E
+Schloss Hüffe	Schloss Hüffe ist ein Ende des 13. Jahrhunderts errichtetes Wasserschloss in der Ortschaft Lashorst der Stadt Preußisch Oldendorf im Kreis Minden-Lübbecke.	52 20 05.99 N	8 30 55.72 E
+Schloss Kalkum	Schloss Kalkum is a water castle in Kalkum in the north of Düsseldorf, about two kilometers northeast of Kaiserwerth.	51 18 14.9 N	6 45 26.7 E
+Schloss Nymphenburg	Nymphenburg Palace is a château in Munich. Its construction was started during the 17th century by the Prince-elector Ferdinand Maria of Bavaria.	48 09 29 N	11 30 13 E
+Schloss Petershagen	Das Schloss Petershagen in Petershagen ist ein Wasserschloss im Stil der Weserrenaissance.	52 22 46.16 N	8 58 18.62 E
+Schloss Rosenstein		48 48 15 N 9 11 30 E
+Schlosskirche (Neustrelitz)	Die Neustrelitzer Schlosskirche wurde durch Friedrich Wilhelm Buttel erbaut und ist dessen Hauptwerk in der Stadt.	53 21 35 N	13 03 32 E
+Schlossplatz Stuttgart		48 46 42.81 N	9 10 47.45 E
+Sestri Levante	Sestri Levante is a town in Liguria in Italy.	44 16 17.76 N	9 23 33 E
+Shokeda	Shokeda is a religious settlement in Israel, in north-west part of Negev, south to Sderot and east to the Gaza Strip.	31 25 19.56 N	34 31 28.2 E
+Sigüeiro, A Barciela, Oroso		42 58 06.42 N	8 26 33.38 W
+Silleda		42 41 49.46 N	8 14 50.28 W
+Singapore	Singapore is a city state at the southern tip of peninsular Malaysia. It is an island approximately 40 by 20 km in size inhabited by more than five million people.	1 18 00 N	103 48 00 E
+Singapore Zoo		1 24 15.9 N	103 47 28.1 E
+Sistiana	Sistiana is a town near Trieste.	45 46 09.98 N	13 38 01.98 E
+Sistine Chapel	The Sistine Chapel is located in the Vatican and is decorated with frescoes by Michelangelo.	41 54 11 N	12 27 16 E
+Sohland am Rotstein	Sohland am Rotstein is a municipality in Saxony, Germany.	51 07 00 N	14 47 00 E
+Sopron	Sopron (pronounced "shop-ron"; German: Ödenburg) is a city in Hungary near the Austrian border. It is located a short train ride from Vienna.	47 41 12 N	16 34 49 E
+Spenge	Spenge is a northrhine-westphalian town in the administrative district Kreis Herford.	52 08 33.29 N	8 28 59.9 E
+Spišský hrad	The ruins of Spiš Castle are situated above the town of Spišské Podhradie and the village of Žehra in the Spiš region in eastern Slovakia.	48 59 58.5 N	20 46 03.3 E
+St. Jürgenskirche (Lilienthal)	The church of St. Jürgen is in the same named district of Lilienthal in the county of Osterholz in Lower Saxony, Germany.	53 10 36 N	8 48 29 E
+St. Maria in der Kupfergasse	St. Maria in der Kupfergasse is a baroque church in Cologne.	50 56 23.2 N	6 57 01.04 E
+Stadtplatz (Steyr)		48 02 20.42 N	14 25 08.89 E
+Stalis		35 17 47.4 N	25 25 25.9 E
+Steigfriedhof	The Steigfriedhof is a cemetery in the Stadtbezirk Bad Cannstatt in Stuttgart.	48 48 41.9 N	9 12 28.95 E
+Stift Göttweig	Göttweig Abbey is a Benedictine monastery in Lower Austria.	48 22 00.2 N	15 36 45.5 E
+Städtisches Lapidarium Stuttgart		48 46 03.36 N	9 10 04.58 E
+Sultanahmet Camii	The Sultan Ahmed Mosque (in Turkish Sultanahmet Camii, in English commonly called the Blue Mosque) is a mosque in Istanbul. It is regarded as one of the greatest masterpieces of Islamic architecture.	41 00 19.3 N	28 58 36.6 E
+Synchrotron Soleil		48 42 33 N	2 08 41 E
+Süleymaniye camii	The Mosque of Suleiman I in Istanbul.	41 00 58.3 N	28 57 50 E
+Tarancón	Tarancón village and municipality in the province of Cuenca, part of the autonomous community of Castile-La Mancha, Spain.	40 00 45.89 N	3 00 14.85 W
+Teixido, Cedeira		43 42 36.72 N	7 59 00.44 W
+Villa romana de Tejada	The ancient roman villa of La Tejeda is an archaeological site from II to V centuries in Quintanilla de la Cueza, Cervatos de la Cueza (Palencia, Spain).	40 58 36 N	4 48 25 W
+Temple Neuf (Strasbourg)		48 35 00 N	7 44 54 E
+Templer Cemetery, Jerusalem	Jerusalem, German Colony, Emek Refaim street 39	31 45 47.46 N	35 13 08.68 E
+Texas State Capitol	The Texas State Capitol, located in Downtown Austin, Texas, is the fourth building to serve as the seat of Texas government.	30 16 29 N	97 44 26 W
+The Dormition Cathedral in Odessa		46 28 31.07 N	30 43 55.42 E
+The Spice Bazaar, Istanbul		41 01 00.7 N	28 58 15.13 E
+Tiberias		32 47 20.04 N	35 31 20.28 E
+Tomiño	Tomiño is a municipality in Galicia, Spain in the province of Pontevedra.	41 59 31.78 N	8 44 32.53 W
+Toosa	Toosa is a village in Punjab.	30 44 45.31 N	75 41 14.53 E
+Topkapı Sarayı	İznik tiles: camp of the Mount Arafat	41 00 45.7 N	28 59 03.25 E
+Torre de San Sadurniño		42 30 25 N	8 49 16 W
+Torre de Vilanova dos Infantes		42 09 58.36 N	7 57 16.62 W
+Torres de Altamira		42 52 39.02 N	8 41 15.17 W
+Torres do Oeste		42 40 35.81 N	8 43 32.45 W
+Torreón dos Andrade		43 24 27.98 N	8 10 17.88 W
+Transfiguration Cathedral in Odessa		46 28 59.44 N	30 43 51.75 E
+Trappentreustraße	The Trappentreustraße is a street in Munich, part of the Mittlerer Ring around the city centre.	48 08 12.34 N	11 32 03.84 E
+Trappentreutunnel	The Trappentreutunnel is a tunnel that runs beneath the Trappentreustraße in the borough Schwanthalerhöhe in Munich.	48 08 08.78 N	11 32 03.17 E
+Trastevere	Restaurant in Via della Lungaretta	41 53 22.54 N	12 28 12.76 E
+Travemünde	Travemünde is a part of Lübeck in Germany at the Baltic Sea.	53 58 00 N	10 52 00 E
+Treuners Altstadtmodell	The Treuner brothers' Altstadtmodell is a scale model which shows the oldtown of Frankfurt am Main prior to the air-raid damages in 1943 and 1944. The ruin model shows the destroyed old town of Frankfurt in spring 1945.	50 06 35 N	8 40 57 E
+Triumphal arch Barcelona		41 23 27 N	2 10 50 E
+Twierdza Osowiec	Dry moat around the fort No 3	53 27 44 N	22 37 38 E
+Třebechovice pod Orebem	Třebechovice pod Orebem is a town in Czech Republic in Hradec Králové Region	50 12 07 N	15 59 38 E
+Uetersen		53 41 14 N	9 40 09 E
+Universidad de Alcalá		40 28 58.53 N	3 21 47.27 W
+Université Lille Nord de France		50 36 33.38 N	3 08 29.72 E
+Upper Darby, Pennsylvania		39 57 40.2 N	75 15 32.06 W
+Urgnano		45 35 50 N	9 41 42 E
+Valdoviño	Valdoviño is a municipality in the province A Coruña, Galicia, Spain.	43 36 32.23 N	8 08 30.84 W
+Valjala church	Valjala church is the oldest stone church in Estonia. The construction begun in 1227.	58 24 30.32 N	22 47 13.92 E
+Valparaíso		33 02 45.4 S	71 36 58.9 W
+Varallo	Varallo is a town in Valsesia, Piedmont, Italy, named also Varallo Sesia.	45 49 10.95 N	8 15 19.01 E
+Varigotti	Varigotti è una frazione del comune di Finale Ligure, in provincia di Savona (riviera ligure di ponente, Liguria, Italia).	44 10 53.83 N	8 23 45.56 E
+Verducido, Pontevedra		42 28 35.96 N	8 37 06.66 W
+Verín	Verín is a municipality in Galicia, in the province of Ourense.	41 56 22.46 N	7 26 19.59 W
+Via dell'Amore (Cinque Terre)	La Via dell'Amore è una passeggiata turistica di circa un chilometro che, costeggiando il mare, congiunge le località di Riomaggiore e Manarola, nelle Cinque Terre, in Liguria (Italia).	44 06 06.07 N	9 44 00.37 E
+Via Dolorosa signs		31 46 46.48 N	35 13 56.63 E
+Viana do Bolo		42 10 46.42 N	7 06 44.8 W
+Vigo	Vigo is a Spanish municipality and the largest city in Galicia.	42 14 00.05 N	8 42 37.59 W
+Vilagarcía de Arousa		42 35 33.08 N	8 46 36.13 W
+Vilamarín	Vilamarín is a municipality in Galicia, in the province of Ourense.	42 27 51.29 N	7 53 23.64 W
+Vilanova de Arousa	Vilanova de Arousa is a municipality in Galicia, Spain in the province of Pontevedra.	42 33 48.42 N	8 49 26.69 W
+Vilar de Santos	Vilar de Santos is a municipality in Galicia, in the province of Ourense.	42 05 10.72 N	7 47 44.37 W
+Vilardevós		41 54 25.21 N	7 18 45.37 W
+Vilariño de Conso		42 09 56.5 N	7 11 02.5 W
+Vilasobroso, Mondariz		42 12 17.3 N	8 27 20.51 W
+Vilassar de Mar	Vilassar de Mar is a village in the county of the Maresme, Catalonia.	41 30 19 N	2 23 34 E
+Villa Berg		48 47 31.34 N	9 12 27.17 E
+Villa d'Este (Tivoli)	The Villa d'Este in Tivoli is a masterpiece of Italian architecture and garden design.	41 57 45 N	12 47 46 E
+Villa Schneider	Villa Schneider è un palazzo storico di Biella (Piemonte, Italia), servito come quartier generale delle SS durante la seconda guerra mondiale.	45 33 49.52 N	8 03 04.87 E
+Village Vanguard	The Village Vanguard is a jazzclub in Greenwich Village (New York City).	40 44 09.64 N	74 00 05.81 W
+Villeneuve-d'Ascq	Villeneuve-d'Ascq is a commune within Lille Metropolis, in northern France	50 37 24 N	3 08 42 E
+Wakayama prefecture	Wakayama Prefecture is located in the Kinki Region of the island of Honshu, Japan.	34 13 33.7 N	135 10 03 E
+Walhalla, Victoria		37 56 37.43 S	146 27 02.75 E
+Walt Disney Concert Hall		34 03 19.36 N	118 14 59.61 W
+Wayside Cross Villenstraße, Bonn-Dottendorf		50 42 15.73 N	7 06 43.18 E
+Weckschnapp		50 56 57.48 N	6 57 55.5 E
+West Lake		30 15 00 N	120 09 00 E
+Whitemarsh Hall		40 04 42 N	75 07 44 W
+Wild fire area at lake Norra Hörken	Norra Hörken is a lake situated between Ludvika and Ljusnarsberg municipalities in central Sweden. This gallery page shows some ecological aspects of a small wildfire in a rather typical Scandinavian forest.	60 02 30 N	14 54 37 E
+Wilhelmsstift Tübingen		48 31 16.19 N	9 03 18.52 E
+Woodlawn Cemetery (Bronx)	Gate on Jerome Avenue	40 53 30 N	73 52 12 W
+Xinzo de Limia	Xinzo de Limia is a municipality in Galicia, in the province of Ourense.	42 03 36 N	7 43 19.87 W
+Yad Vashem	The memorial of the murdered jews of Suwałki and the neighbour communities, Yad Vashem, Jerusalem	31 46 23.55 N	35 10 29.2 E
+Yao	Yao (八尾市, Yao-shi) is a city in Osaka, Japan.	34 37 36.9 N	135 36 03 E
+Zwangsarbeitslager Rees-Groin und Bienen		51 46 44.76 N	6 24 25.92 E
+Zwehrenturm	The Zwehrenturm from 1330 is a remain of Kassel's medieval defensive wall. Temporary it contained an observatory.	51 18 49 N	9 29 54 E
+École centrale de Lille	École Centrale de Lille is a graduate engineering school located in campus Lille I within Université Lille Nord de France.	50 36 21.62 N	3 08 13.63 E
+Église de Saint-Paul de Frontignan		43 26 50.47 N	3 45 18.66 E
+Église des Jésuites (Molsheim)		48 32 25.3 N	7 29 45 E
+Église Notre-Dame (Guebwiller)		47 54 20.75 N	7 12 52.56 E
+Église Saint-Michel d'Ernolsheim-lès-Saverne	Bells	48 47 27.85 N	7 22 47.57 E
+Église Saint-Pierre-de-Rhèdes		43 35 16.22 N	3 04 43.64 E
+Église Saint-Pierre-Saint-Paul de Rueil-Malmaison		48 52 35.4 N	2 10 53.15 E
+Église Saints-Pierre-et-Paul (Andlau)		48 23 16.3 N	7 24 54.3 E
+Église Saints-Pierre-et-Paul (Neuwiller-lès-Saverne)		48 49 25 N	7 24 20 E
+Église Saints-Pierre-et-Paul (Wissembourg)		49 02 14 N	7 56 30 E
+Église St Cyriaque (Altorf)		48 31 22.7 N	7 31 50 E
+Église St Jean-Baptiste (Saint-Jean-Saverne)		48 46 18.7 N	7 21 48.5 E
+Église St Léger (Guebwiller)		47 54 42.1 N	7 12 33.75 E
+Église St Maurice (Ebersmunster)		48 18 39.5 N	7 31 37 E
+Église St Pierre le Jeune catholique (Strasbourg)		48 35 18.35 N	7 44 55.75 E
+Église St Pierre le Jeune protestante (Strasbourg)		48 35 08 N	7 44 47 E
+Église St Thomas protestante (Strasbourg)		48 34 47 N	7 44 44 E
+Église Ste Madeleine (Strasbourg)		48 34 48 N	7 45 17 E
+Đình Bảng	Bảng Communal House (Đình Bảng in Vietnamese) is one of largest and finest village communal houses in Việt Nam. It is located in Đình Bảng commune, Từ Sơn district, Bắc Ninh province.	21 06 29.99 N	105 57 06.31 E
+Боровск	Borovsk	55 12 27.19 N	36 29 05.05 E
+กรุงเทพมหานคร	Bangkok	13 45 08 N	100 29 38 E
+სვეტიცხოველი		41 50 31 N	44 43 16 E
+ჯვარი		41 30 06.84 N	44 26 24.72 E
+鹿児島市	Kagoshima(鹿児島市; -shi) is a city in Japan and the capital city of Kagoshima Prefecture.	31 35 48.5 N	130 33 25.7 E
+薩摩川内市	Satsumasendai is a city in Kagoshima prefecture, Japan.	31 48 48.5 N	130 18 14.3 E
+上海	Shanghai is the largest city in China and is divided into 18 districts and one county (the island in the Yangtze River). It is located on the coast of eastern China at the mouth of the Chang Jiang (Yangtze River), and borders the provinces of Jiangsu and Zhejiang.	31 10 00 N	121 29 00 E
+中南海	Zhongnanhai (Chinese: 中南海; pinyin: Zhōngnánhăi) is a complex of buildings in Beijing, China which serves as the central headquarters for the Communist Party of China and the government of the People's Republic of China.	39 54 41 N	116 22 50 E
+九寨沟	Jiuzhaigou Valley (Chinese: 九寨沟; pinyin: Jiǔzhàigōu; lit. "Nine Stockades Gully") is a nature reserve in Aba(阿坝) Tibetan and Qiang Autonomous District, northern Sichuan province, China. It is known for its many multi-level waterfalls and colorful lakes, and was declared a UNESCO World Heritage Site in 1992.	33 09 34 N	103 52 40 E
+云南	Yunnan(云南) is a Chinese southwest border province, with the most varied nationalities in China. There are 52 nationalities of people living in Yunnan, out of 56 total throughout China.	25 03 00 N	101 52 00 E
+京都市	Kyoto is a city in Japan. It was the capital of Japan from 794 to 1869.	35 00 41.8 N	135 46 05.2 E
+兵馬俑	Terracotta Army	34 23 05.7 N	109 16 23.1 E
+別府市	Beppu is a famous onsen city in Oita Prefecture on the island of Kyushu in Japan.	33 17 04.6 N	131 29 28.6 E
+北九州市	Kitakyūshū is a city in Fukuoka Prefecture on the island of Kyushu, Japan.	33 53 00.3 N	130 52 30.7 E
+北京动物园	beijing zoo lies west of Xizhimen and is the western part of the Beijing, China. It is one of the largest zoos in mainland china.	39 56 19 N	116 20 00 E
+北海公园	中文: 北海公园位于中国北京市城区的中偏北部,故宫和景山的西北侧,始建于辽代,是世界上现存建园时间最早的皇家宫苑。	39 55 28 N	116 22 59 E
+南京	Nanjing (南京) is the capital of Jiangsu Province of China. It was the Chinese capital from 1927-1949.	32 03 00 N	118 46 00 E
+南法華寺	Minamihokke-ji is the Buddhist temple in Takatori, Nara prefecture, Japan.	34 25 35.1 N	135 48 35.5 E
+台南市		22 59 00 N	120 11 00 E
+和歌山市	Wakayama (和歌山市, Wakayama-shi) is the capital city of Wakayama Prefecture in the Kansai region of Japan.	34 13 49.3 N	135 10 14.7 E
+四川	Sichuan(四川) is the most densely populated province in west China. It is famous for its peppery dishes.	30 08 00 N	102 56 00 E
+圆明园	Yuanmingyuan (pinyin: Yuanmingyuan, 圆明园), or the old Summer Palace in Peking.	40 00 26 N	116 17 33 E
+大津市	Otsu is a city in Japan. It was the capital of Japan from 667 to 672.	35 01 04.1 N	135 51 17 E
+大阪市	Osaka	34 41 37.5 N	135 30 07.6 E
+天坛	Temple of Heaven in Beijing.	39 52 56.1 N	116 24 23.7 E
+天安門	Tiananmen (Gate of Heavenly Peace) in Beijing was the southern gate of the Imperial City in Beijing.	39 54 26.4 N	116 23 27.9 E
+天安门广场	Mausoleum of Mao Zedong	39 54 12 N	116 23 30 E
+宇治市	Uji is a city in Kyoto prefecture. The Byodoin (an ancient Buddhist temple) and the Ujigami Shrine are famous landmarks in Uji.	34 53 03.7 N	135 47 59.3 E
+小田原市	Odawara, Kanagawa	35 15 52.6 N	139 09 08 E
+屋久島	Yakushima island	30 20 00 N	130 30 00 E
+川崎市	Kawasaki, Kanagawa	35 31 51.2 N	139 42 10.8 E
+广东	Guangdong (广东) is a coastal province in southern China adjacent to Hongkong and Macao.	23 24 00 N	113 30 00 E
+广州	Guangzhou is the capital of Guangdong Province in southern China. The city was formerly known internationally as Canton City or simply Canton.	23 07 43.67 N	113 15 32.31 E
+広島市	Hiroshima is one of largest cities in Japan and the capital of Hiroshima prefecture.	34 23 06.9 N	132 27 19.1 E
+徳島市	Tokushima is the capital city of Tokushima prefecture on the island of Kyushu in Japan.	34 04 13 N	134 33 17.8 E
+成都	Chengdu is the capital of Sichuan province in China.	30 39 49 N	104 04 00 E
+景山公园	Jingshan Park, Dongcheng District, Beijing.	39 55 24.5 N	116 23 26.2 E
+杭州	Hangzhou (杭州) is a picturesque city in south China. It is the capital of Zhejiang Province and visited by Marco Polo.	30 15 00 N	120 10 00 E
+武汉	Wuhan is the capital of the Chinese province of Hubei	30 34 21 N	114 16 45 E
+滕王阁		28 41 02.76 N	115 52 32.88 E
+熊本市	Kumamoto is the capital city of Kumamoto Prefecture, on the island of Kyushu, Japan.	32 48 10.8 N	130 42 28.3 E
+相模原市	Sagamihara, Kanagawa	35 34 17.1 N	139 22 23.3 E
+祇園	Gion (祇園) is a district of Kyoto, Japan, originally developed in the middle ages.	35 00 13 N	135 46 30 E
+福岡市	Fukuoka, Fukuoka	33 35 24.5 N	130 24 06.2 E
+紫禁城	The Forbidden City (紫禁城), located at the centre of Beijing, China, was the imperial palace of the last two imperial dynasties of China (from 1420 to 1924).	39 54 50.1 N	116 23 27.6 E
+西安	Xi'an is an ancient city located in north central China. It was the capital of various dynasties from 1046 B.C. to 907 A.D, and it has been known under a number of different names including most notably Chang'an during the Tang dynasty.	34 16 00 N	108 57 00 E
+逗子市	Zushi (逗子市 Zushi-shi) is a city located in Kanagawa, Japan.	35 17 44.2 N	139 34 49.2 E
+那覇市		26 12 44.4 N	127 40 44.8 E
+鎌倉	Zeniarai Benten shrine	35 19 09.3 N	139 32 48.1 E
+颐和园	The Summer Palace (pinyin: Yiheyuan, 颐和园) is a former imperial palace in northwest of Beijing, China. It has been transformed in a public garden.	39 59 51 N	116 16 08.04 E
+香港	Hong Kong	22 16 01 N	114 11 17 E
+高松市	日本語: 高松市は日本の瀬戸内海沿岸に位置する香川県の県都である。四国の北端に位置することや本州に近いことから、港町として発展してきた歴史をもつ。	34 20 34.1 N	134 02 47.8 E
+高雄市	Kaohsiung is a city in Taiwan.	22 38 00 N	120 16 00 E
+
diff --git a/tim/prune/lang/prune-texts_cz.properties b/tim/prune/lang/prune-texts_cz.properties
index 54093a8..60b7b22 100644
--- a/tim/prune/lang/prune-texts_cz.properties
+++ b/tim/prune/lang/prune-texts_cz.properties
@@ -767,6 +767,7 @@ logic.or=nebo
 url.googlemaps=maps.google.cz
 wikipedia.lang=cs
 openweathermap.lang=en
+webservice.opencachingcom.lang=cs
 
 # Cardinals for 3d plots
 cardinal.n=N
diff --git a/tim/prune/lang/prune-texts_de.properties b/tim/prune/lang/prune-texts_de.properties
index 4169c91..d9c50b4 100644
--- a/tim/prune/lang/prune-texts_de.properties
+++ b/tim/prune/lang/prune-texts_de.properties
@@ -386,6 +386,7 @@ dialog.mapillary.nonefound=Keine Fotos gefunden
 dialog.wikipedia.column.name=Artikelname
 dialog.wikipedia.column.distance=Entfernung
 dialog.wikipedia.nonefound=Keine Punkte gefunden
+dialog.wikipedia.gallery=Bilder
 dialog.geocaching.nonefound=Keine Punkte gefunden
 dialog.correlate.notimestamps=Die Punkte enthalten keine Zeitangaben, deshalb k\u00f6nnen die Fotos nicht zugeordnet werden.
 dialog.correlate.nouncorrelatedphotos=Alle Fotos sind schon zugeordnet.\nWollen Sie trotzdem fortfahren?
@@ -649,7 +650,7 @@ confirm.correlateaudios.multi=Audios wurden korreliert
 # Tips
 tip.title=Tipp
 tip.useamapcache=Mit lokal-gespeicherten Kartenkacheln (Einstellungen -> Karten auf Festplatte speichern)\nk\u00f6nnen Sie die Darstellung beschleunigen und Netzwerkverkehr reduzieren.
-tip.learntimeparams=Wenn Sie Track -> Zeitparameter erlernen mit Ihren Tracks benutzen\ndann werden die berechneten Werten genauer.
+tip.learntimeparams=Wenn Sie Track -> Zeitparameter erlernen mit Ihren Tracks benutzen\ndann werden die berechneten Werte genauer.
 tip.downloadsrtm=Sie k\u00f6nnen diese Funktion beschleunigen indem Sie\nOnline -> SRTM Dateien herunterladen aufrufen\num die Daten lokal zu speichern.
 tip.usesrtmfor3d=Dieser Track hat keine H\u00f6heninformation.\nSie k\u00f6nnen die SRTM Funktionen verwenden, um\nH\u00f6henwerte abzusch\u00e4tzen.
 tip.manuallycorrelateone=Mit mindestens einem manuell verbundenen Element kann die Zeitdifferenz automatisch berechnet werden.
diff --git a/tim/prune/lang/prune-texts_de_CH.properties b/tim/prune/lang/prune-texts_de_CH.properties
index d4e0e1e..1dbd0fd 100644
--- a/tim/prune/lang/prune-texts_de_CH.properties
+++ b/tim/prune/lang/prune-texts_de_CH.properties
@@ -381,6 +381,7 @@ dialog.mapillary.nonefound=Kei F\u00f6telis gfunde
 dialog.wikipedia.column.name=Artikelname
 dialog.wikipedia.column.distance=Entf\u00e4rnig
 dialog.wikipedia.nonefound=Kei Wiki-Iitr\u00e4ge gfunde
+dialog.wikipedia.gallery=Fotis
 dialog.geocaching.nonefound=Kei C�ches gfunde
 dialog.correlate.notimestamps=Es h\u00e4t kei Ziitst\u00e4mpel inem Track inn\u00e4, so s'isch n\u00f6d m\u00f6glech die F\u00f6telis zu korrelier\u00e4.
 dialog.correlate.nouncorrelatedphotos=Alle F\u00f6telis sin scho korreliert.\nWend Sie trotzdem fortsetz\u00e4?
diff --git a/tim/prune/lang/prune-texts_en.properties b/tim/prune/lang/prune-texts_en.properties
index 785a62e..0d74cf1 100644
--- a/tim/prune/lang/prune-texts_en.properties
+++ b/tim/prune/lang/prune-texts_en.properties
@@ -386,6 +386,7 @@ dialog.mapillary.nonefound=No photos found
 dialog.wikipedia.column.name=Article name
 dialog.wikipedia.column.distance=Distance
 dialog.wikipedia.nonefound=No wikipedia entries found
+dialog.wikipedia.gallery=Gallery
 dialog.geocaching.nonefound=No geocaches found
 dialog.correlate.notimestamps=There are no timestamps in the data points, so there is nothing to correlate with the photos.
 dialog.correlate.nouncorrelatedphotos=There are no uncorrelated photos.\nAre you sure you want to continue?
diff --git a/tim/prune/lang/prune-texts_hu.properties b/tim/prune/lang/prune-texts_hu.properties
index c083f63..0cdc442 100644
--- a/tim/prune/lang/prune-texts_hu.properties
+++ b/tim/prune/lang/prune-texts_hu.properties
@@ -387,6 +387,7 @@ dialog.mapillary.nonefound=Nem tal\u00e1lhat\u00f3k f\u00e9nyk\u00e9pek
 dialog.wikipedia.column.name=Sz\u00f3cikk neve
 dialog.wikipedia.column.distance=T\u00e1vols\u00e1g
 dialog.wikipedia.nonefound=Nem tal\u00e1lhat\u00f3 Wikip\u00e9dia sz\u00f3cikk
+dialog.wikipedia.gallery=Gal�ria
 dialog.correlate.notimestamps=Nincsenek id\u0151b\u00e9lyegek az adatpontokon, \u00edgy nem feleltethet\u0151 meg semmi a f\u00e9nyk\u00e9pekkel.
 dialog.correlate.nouncorrelatedphotos=Nincsenek megfeleltetlen f\u00e9nyk\u00e9pek.\nBiztos benne, hogy folytatja?
 dialog.correlate.nouncorrelatedaudios=Nincsenek megfeleltetlen hangok.\nBiztos benne, hogy folytatja?
diff --git a/tim/prune/lang/prune-texts_nl.properties b/tim/prune/lang/prune-texts_nl.properties
index 548f9b6..428913f 100644
--- a/tim/prune/lang/prune-texts_nl.properties
+++ b/tim/prune/lang/prune-texts_nl.properties
@@ -86,6 +86,7 @@ function.exportsvg=Export SVG
 function.exportimage=Bestand exporteren
 function.editwaypointname=Hernoem waypoint
 function.compress=Route comprimeren
+function.marklifts=Makeer skiliften 
 function.deleterange=Verwijder reeks
 function.croptrack=Route bijknippen
 function.interpolate=Interpoleer punten
@@ -103,6 +104,7 @@ function.distances=Afstanden
 function.fullrangedetails=Reeks details
 function.estimatetime=Geschatte tijd
 function.learnestimationparams=Parameters voor geschatte tijd
+function.autoplay=Route afspelen
 function.setmapbg=Instellen kaart achtergrond
 function.setpaths=Instellen programmapaden
 function.selectsegment=Selecteer huidige segment
@@ -115,6 +117,7 @@ function.downloadsrtm=Downloaden SRTM tegels
 function.getwikipedia=Wikipedia artikelen uit de buurt ophalen
 function.searchwikipedianames=Wikipedia zoeken op naam
 function.searchopencachingde=OpenCaching.de zoeken
+function.mapillary=Mapillary.com zoeken
 function.downloadosm=Downloaden OSM data voor gebied
 function.duplicatepoint=Dupliceer punt
 function.setcolours=Instellen kleuren
@@ -383,6 +386,7 @@ dialog.mapillary.nonefound=Geen foto's gevonden
 dialog.wikipedia.column.name=Artikelnaam
 dialog.wikipedia.column.distance=Afstand
 dialog.wikipedia.nonefound=Geen punten gevonden
+dialog.wikipedia.gallery=Galerie
 dialog.geocaching.nonefound=Geen punten gevonden
 dialog.correlate.notimestamps=Er zit geen tijdinformatie in de punten, dus kunnen ze niet aan foto's gekoppeld worden.
 dialog.correlate.nouncorrelatedphotos=Er zijn geen ongekoppelde foto's.\nWeet u zeker dat u wilt doorgaan?
@@ -593,6 +597,10 @@ dialog.deletebydate.column.delete=Verwijderen
 dialog.setaltitudetolerance.text.metres=Grens (in meters) waaronder kleine klimmen en afdalingen worden genegeerd
 dialog.setaltitudetolerance.text.feet=Grens (in feet) waaronder kleine klimmen en afdalingen worden genegeerd
 dialog.autoplay.duration=Duur (sec)
+dialog.autoplay.usetimestamps=Gebruik tijdinformatie
+dialog.autoplay.rewind=Terugspoelen
+dialog.autoplay.pause=Pauzeren
+dialog.autoplay.play=Afspelen
 
 # 3d window
 dialog.3d.title=GpsPrune in 3D
diff --git a/tim/prune/lang/prune-texts_ro.properties b/tim/prune/lang/prune-texts_ro.properties
index 0a1f020..45c62a7 100644
--- a/tim/prune/lang/prune-texts_ro.properties
+++ b/tim/prune/lang/prune-texts_ro.properties
@@ -388,6 +388,7 @@ dialog.wikipedia.column.name=Nume
 dialog.wikipedia.column.distance=Distan\u0163\u0103
 dialog.wikipedia.nonefound=Nu a fost g\u0103sit
 dialog.geocaching.nonefound=Nu a fost g\u0103sit
+dialog.wikipedia.gallery=Galerie
 dialog.correlate.notimestamps=Corelarea cu fotografiile nu se poate realiza pentru c\u0103 \u00een puncte nu exist\u0103 informa\u021bie cronologic\u0103
 dialog.correlate.nouncorrelatedphotos=Nu exist\u0103 fotografii necorelate. Continui?
 dialog.correlate.nouncorrelatedaudios=Nu exist\u0103 clipuri audio necorelate. Continui?
diff --git a/tim/prune/lang/prune-texts_uk.properties b/tim/prune/lang/prune-texts_uk.properties
index 380e564..9624351 100644
--- a/tim/prune/lang/prune-texts_uk.properties
+++ b/tim/prune/lang/prune-texts_uk.properties
@@ -7,15 +7,12 @@ menu.file.addphotos=\u0414\u043e\u0434\u0430\u0442\u0438 \u0444\u043e\u0442\u043
 menu.file.recentfiles=\u041f\u0440\u0438\u0439\u043d\u044f\u0442\u0456 \u0444\u0430\u0439\u043b\u0438
 menu.file.save=\u0417\u0431\u0435\u0440\u0435\u0433\u0442\u0438 \u044f\u043a \u0442\u0435\u043a\u0441\u0442
 menu.file.exit=\u0412\u0438\u0445\u0456\u0434
+menu.online=\u041e\u043d\u043b\u0430\u0439\u043d
 menu.track=\u0422\u0440\u0435\u043a
 menu.track.undo=\u0421\u043a\u0430\u0441\u0443\u0432\u0430\u0442\u0438
 menu.track.clearundo=\u041e\u0447\u0438\u0441\u0442\u0438\u0442\u0438 \u0441\u043f\u0438\u0441\u043e\u043a \u0437\u043c\u0456\u043d
 menu.track.markrectangle=\u041f\u043e\u0437\u043d\u0430\u0447\u0438\u0442\u0438 \u0442\u043e\u0447\u043a\u0438 \u0443 \u043f\u0440\u044f\u043c\u043e\u043a\u0443\u0442\u043d\u0438\u043a\u0443
 function.deletemarked=\u0412\u0438\u043b\u0443\u0447\u0438\u0442\u0438 \u043f\u043e\u0437\u043d\u0430\u0447\u0435\u043d\u0456 \u0442\u043e\u0447\u043a\u0438
-function.rearrangewaypoints=\u041f\u0435\u0440\u0435\u0432\u0438\u0437\u043d\u0430\u0447\u0438\u0442\u0438 \u0456\u043d\u0442\u0435\u0440\u0432\u0430\u043b\u0438
-dialog.rearrange.tostart=\u0423\u0441\u0435 \u043d\u0430 \u043f\u043e\u0447\u0430\u0442\u043e\u043a \u0444\u0430\u0439\u043b\u0443
-dialog.rearrange.toend=\u0423\u0441\u0435 \u043d\u0430 \u043a\u0456\u043d\u0435\u0446\u044c \u0444\u0430\u0439\u043b\u0443
-dialog.rearrange.tonearest=\u041f\u0435\u0440\u0435\u043c\u0456\u0441\u0442\u0438\u0442\u0438 \u0434\u043e \u043d\u0430\u0439\u0431\u043b\u0438\u0436\u0447\u043e\u0457
 menu.range=\u0406\u043d\u0442\u0435\u0440\u0432\u0430\u043b
 menu.range.all=\u0412\u0438\u0431\u0440\u0430\u0442\u0438 \u0443\u0441\u0456
 menu.range.none=\u0421\u043a\u0430\u0441\u0443\u0432\u0430\u0442\u0438 \u0432\u0438\u0431\u0456\u0440\u043a\u0443
@@ -92,6 +89,7 @@ function.croptrack=\u041e\u0431\u0440\u0456\u0437\u0430\u0442\u0438 \u0442\u0440
 function.interpolate=\u0406\u043d\u0442\u0435\u0440\u043f\u043e\u043b\u044f\u0446\u0456\u044f \u0442\u043e\u0447\u043e\u043a
 function.addtimeoffset=\u0414\u043e\u0434\u0430\u0442\u0438 \u043f\u043e\u0437\u043d\u0430\u0447\u043a\u0443 \u0447\u0430\u0441\u0443
 function.addaltitudeoffset=\u0414\u043e\u0434\u0430\u0442\u0438 \u043f\u043e\u0437\u043d\u0430\u0447\u043a\u0443 \u0432\u0438\u0441\u043e\u0442\u0438
+function.rearrangewaypoints=\u041f\u0435\u0440\u0435\u0432\u0438\u0437\u043d\u0430\u0447\u0438\u0442\u0438 \u0456\u043d\u0442\u0435\u0440\u0432\u0430\u043b\u0438
 function.convertnamestotimes=\u041f\u0435\u0440\u0435\u0442\u0432\u043e\u0440\u0438\u0442\u0438 \u0456\u043c\u2019\u044f \u0448\u043b\u044f\u0445\u043e\u0432\u043e\u0457 \u0442\u043e\u0447\u043a\u0438 \u0443 \u0447\u0430\u0441
 function.deletefieldvalues=\u0412\u0438\u043b\u0443\u0447\u0438\u0442\u0438 \u0437\u043d\u0430\u0447\u0435\u043d\u043d\u044f \u043f\u043e\u043b\u044f
 function.findwaypoint=\u0417\u043d\u0430\u0439\u0442\u0438 \u0448\u043b\u044f\u0445\u043e\u0432\u0443 \u0442\u043e\u0447\u043a\u0443
@@ -223,12 +221,32 @@ dialog.exportkml.altitude=\u0410\u0431\u0441\u043e\u043b\u044e\u0442\u043d\u0456
 dialog.exportkml.kmz=\u0421\u0442\u0438\u0441\u043d\u0435\u043d\u043d\u044f \u0434\u043b\u044f kmz-\u0444\u0430\u0439\u043b\u0443
 dialog.exportkml.exportimages=\u0415\u043a\u0441\u043f\u043e\u0440\u0442 \u0435\u0441\u043a\u0456\u0437\u0443 \u0432 kmz
 dialog.exportkml.trackcolour=\u041a\u043e\u043b\u0456\u0440 \u0442\u0440\u0435\u043a\u0443
+dialog.rearrange.tostart=\u0423\u0441\u0435 \u043d\u0430 \u043f\u043e\u0447\u0430\u0442\u043e\u043a \u0444\u0430\u0439\u043b\u0443
+dialog.rearrange.toend=\u0423\u0441\u0435 \u043d\u0430 \u043a\u0456\u043d\u0435\u0446\u044c \u0444\u0430\u0439\u043b\u0443
+dialog.rearrange.tonearest=\u041f\u0435\u0440\u0435\u043c\u0456\u0441\u0442\u0438\u0442\u0438 \u0434\u043e \u043d\u0430\u0439\u0431\u043b\u0438\u0436\u0447\u043e\u0457
+dialog.about.yes=\u0422\u0430\u043a
+dialog.about.no=\u041d\u0456
+
+# Buttons
+button.ok=\u0413\u0430\u0440\u0430\u0437\u0434
+button.cancel=\u0412\u0456\u0434\u043c\u0456\u043d\u0430
+button.yes=\u0422\u0430\u043a
+button.no=\u041d\u0456
 
-# External urls
+# Display components
+display.nodata=\u0416\u043e\u0434\u043d\u0438\u0445 \u0434\u0430\u043d\u0438\u0445 \u043d\u0435 \u0437\u0430\u0432\u0430\u043d\u0442\u0430\u0436\u0435\u043d\u043e
+details.trackdetails=\u041f\u043e\u0434\u0440\u043e\u0431\u0438\u0446\u0456 \u0442\u0440\u0435\u043a\u0443
+details.track.points=\u0422\u043e\u0447\u043a\u0438
+details.track.file=\u0424\u0430\u0439\u043b
+details.pointdetails=\u041f\u043e\u0434\u0440\u043e\u0431\u0438\u0446\u0456 \u0442\u043e\u0447\u043a\u0438
+details.nopointselection=\u0422\u043e\u0447\u043a\u0443 \u043d\u0435 \u0432\u0438\u0431\u0440\u0430\u043d\u043e
+details.norangeselection=\u0414\u0456\u0430\u043f\u0430\u0437\u043e\u043d \u043d\u0435 \u0432\u0438\u0431\u0440\u0430\u043d\u043e
+details.rangedetails=\u041f\u043e\u0434\u0440\u043e\u0431\u0438\u0446\u0456 \u0434\u0456\u0430\u043f\u0430\u0437\u043e\u043d\u0443
+details.lists.photos=\u0421\u0432\u0456\u0442\u043b\u0438\u043d\u0438
+details.photodetails=\u041f\u043e\u0434\u0440\u043e\u0431\u0438\u0446\u0456 \u0441\u0432\u0456\u0442\u043b\u0438\u043d\u0438
+details.nophoto=\u0421\u0432\u0456\u0442\u043b\u0438\u043d\u0443 \u043d\u0435 \u0432\u0438\u0431\u0440\u0430\u043d\u043e
+
+# External urls and services
 url.googlemaps=maps.google.com.ua
 wikipedia.lang=uk
 openweathermap.lang=ua
-
-# Below here is still Russian
-#############################
-
diff --git a/tim/prune/readme.txt b/tim/prune/readme.txt
index 8c92694..8fe5393 100644
--- a/tim/prune/readme.txt
+++ b/tim/prune/readme.txt
@@ -1,5 +1,5 @@
-GpsPrune version 18
-===================
+GpsPrune version 18.1
+=====================
 
 GpsPrune is an application for viewing, editing and managing coordinate data from GPS systems,
 including format conversion, charting, 3d visualisation, audio and photo correlation, and online resource lookup.
@@ -17,7 +17,7 @@ Running
 =======
 
 To run GpsPrune from the jar file, simply call it from a command prompt or shell:
-   java -jar gpsprune_18.jar
+   java -jar gpsprune_18.1.jar
 
 If the jar file is saved in a different directory, you will need to include the path.
 Depending on your system settings, you may be able to click or double-click on the jar file
@@ -25,9 +25,17 @@ in a file manager window to execute it.  A shortcut, menu item, alias, desktop i
 or other link can of course be made should you wish.
 
 To specify a language other than the default, use an additional parameter, eg:
-   java -jar gpsprune_18.jar --lang=DE
+   java -jar gpsprune_18.1.jar --lang=DE
 
 
+New with version 18.1
+=====================
+The following fixes and additions were made since version 18:
+  - Fix for duration rounding bug affecting sub-second timestamps
+  - Wikipedia search now also includes galleries from wikimedia
+  - Photo popup window now gets updated when the track selection changes
+  - Small improvements to Ukrainian, Dutch translations
+
 New with version 18
 ===================
 The following features were added since version 17:

diff --git a/tim/prune/function/GetWikipediaFunction.java b/tim/prune/function/GetWikipediaFunction.java
index be33a95..804ba71 100644
--- a/tim/prune/function/GetWikipediaFunction.java
+++ b/tim/prune/function/GetWikipediaFunction.java
@@ -1,6 +1,8 @@
 package tim.prune.function;
 
+import java.io.BufferedReader;
 import java.io.InputStream;
+import java.io.InputStreamReader;
 import java.net.URL;
 import java.util.ArrayList;
 
@@ -10,14 +12,16 @@ import javax.xml.parsers.SAXParserFactory;
 import tim.prune.App;
 import tim.prune.I18nManager;
 import tim.prune.data.DataPoint;
+import tim.prune.data.Distance;
 import tim.prune.data.Field;
 import tim.prune.data.Latitude;
 import tim.prune.data.Longitude;
+import tim.prune.data.UnitSetLibrary;
 import tim.prune.function.search.GenericDownloaderFunction;
 import tim.prune.function.search.SearchResult;
 
 /**
  * Function to load nearby point information from Wikipedia
  * according to the currently viewed area
  */
 public class GetWikipediaFunction extends GenericDownloaderFunction
@@ -57,7 +61,7 @@ public class GetWikipediaFunction extends GenericDownloaderFunction
 
 
 	/**
-	 * Run method to call geonames in separate thread
+	 * Run method to get the nearby points in a separate thread
 	 */
 	public void run()
 	{
@@ -77,7 +81,10 @@ public class GetWikipediaFunction extends GenericDownloaderFunction
 			lon = point.getLongitude().getDouble();
 		}
 
-		// Firstly try the local language
+		// Before we ask geonames online, let's get wikimedia galleries first
+		searchWikimediaGalleries(lat, lon);
+
+		// For geonames, firstly try the local language
 		String lang = I18nManager.getText("wikipedia.lang");
 		submitSearch(lat, lon, lang);
 		// If we didn't get anything, try a secondary language
@@ -129,7 +136,7 @@ public class GetWikipediaFunction extends GenericDownloaderFunction
 		} catch (Exception e) {}
 		// Add track list to model
 		ArrayList<SearchResult> trackList = xmlHandler.getTrackList();
-		_trackListModel.addTracks(trackList);
+		_trackListModel.addTracks(trackList, true);
 
 		// Show error message if any
 		if (_trackListModel.isEmpty())
@@ -171,4 +178,61 @@ public class GetWikipediaFunction extends GenericDownloaderFunction
 		_cancelled = true;
 		_dialog.dispose();
 	}
+
+	/**
+	 * Search the local wikimedia index to see if there are any galleries nearby
+	 * @param inLat latitude
+	 * @param inLon longitude
+	 */
+	private void searchWikimediaGalleries(double inLat, double inLon)
+	{
+		BufferedReader reader = null;
+		try
+		{
+			InputStream in = GetWikipediaFunction.class.getResourceAsStream("/tim/prune/function/search/wikimedia_galleries.txt");
+			reader = new BufferedReader(new InputStreamReader(in));
+			if (reader != null)
+			{
+				ArrayList<SearchResult> trackList = new ArrayList<SearchResult>();
+				DataPoint herePoint = new DataPoint(new Latitude(inLat, Latitude.FORMAT_DEG), new Longitude(inLon, Longitude.FORMAT_DEG), null);
+				// Loop through the file line by line, looking for nearby points
+				String line = null;
+				while ((line = reader.readLine()) != null)
+				{
+					String[] lineComps = line.split("\t");
+					if (lineComps.length == 4)
+					{
+						DataPoint p = new DataPoint(new Latitude(lineComps[2]), new Longitude(lineComps[3]), null);
+						double distFromHere = Distance.convertRadiansToDistance(
+							DataPoint.calculateRadiansBetween(p, herePoint), UnitSetLibrary.UNITS_KILOMETRES);
+						if (distFromHere < MAX_DISTANCE)
+						{
+							SearchResult gallery = new SearchResult();
+							gallery.setTrackName(I18nManager.getText("dialog.wikipedia.gallery") + ": " + lineComps[0]);
+							gallery.setDescription(lineComps[1]);
+							gallery.setLatitude(lineComps[2]);
+							gallery.setLongitude(lineComps[3]);
+							gallery.setWebUrl("https://commons.wikimedia.org/wiki/" + lineComps[0]);
+							gallery.setLength(distFromHere * 1000.0); // convert from km to m
+							trackList.add(gallery);
+						}
+					}
+				}
+				_trackListModel.addTracks(trackList, true);
+			}
+		}
+		catch (java.io.IOException e) {
+			System.err.println("Exception trying to read wikimedia file : " + e.getMessage());
+		}
+		catch (NullPointerException e) {
+			System.err.println("Couldn't find wikimedia file : " + e.getMessage());
+		}
+		finally
+		{
+			try {
+				reader.close();
+			}
+			catch (Exception e) {} // ignore
+		}
+	}
 }
@@ -10,14 +12,16 @@ import javax.xml.parsers.SAXParserFactory;
 
 /**
- * Function to load nearby point information from Wikipedia
+ * Function to load nearby point information from Wikipedia (and Wikimedia)
  * according to the currently viewed area
  */
-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-grass/gpsprune.git



More information about the Pkg-grass-devel mailing list